import React from 'react';
import Info from './components/Info';

const styles = {
    root: {
        width: '100%',
    },
    flex: {
        flex: 1,
    },
    menuButton: {
        marginLeft: -12,
        marginRight: 20,
    },
};

export default class PortalLayout extends React.Component {
    constructor(props){
        super(props);
        this.state = {};
    }

    onFilterChange =(e) => {
        let {target: {value}} = e
        this.props.layoutActions.updateFilter(value)
    }

    render() {
        let {
            specSelectors,
            specActions,
            getComponent,
            layoutSelectors,
            oas3Selectors,
            oas3Actions
        } = this.props

        let info = specSelectors.info()
        let basePath = specSelectors.basePath()
        let host = specSelectors.host()
        let securityDefinitions = specSelectors.securityDefinitions()
        let externalDocs = specSelectors.externalDocs()
        let schemes = specSelectors.schemes()
        let servers = specSelectors.servers()

        let Operations = getComponent("operations", true)
        let Models = getComponent("Models", true)
        let AuthorizeBtn = getComponent("authorizeBtn", true)
        let Row = getComponent("Row")
        let Col = getComponent("Col")
        let Servers = getComponent("Servers")
        let Errors = getComponent("errors", true)

        let isLoading = specSelectors.loadingStatus() === "loading"
        let isFailed = specSelectors.loadingStatus() === "failed"
        let filter = layoutSelectors.currentFilter()

        let inputStyle = {}
        if(isFailed) inputStyle.color = "red"
        if(isLoading) inputStyle.color = "#aaa"

        const Schemes = getComponent("schemes")

        const isSpecEmpty = !specSelectors.specStr()
        const VersionStamp = getComponent("VersionStamp")

        let url = specSelectors.url()
        let version = info.get("version")
        let title = info.get("title")

        this.props.integrator.setHeader({
            url,
            version,
            title
        });

        if(isSpecEmpty) {
            let loadingMessage
            if(isLoading) {
                loadingMessage = <div className="loading"></div>
            } else {
                loadingMessage = <h4>No API definition provided.</h4>
            }

            return <div className="swagger-ui">
                <div className="loading-container">
                    {loadingMessage}
                </div>
            </div>
        }

        return (

            <div className='swagger-ui'>
                <div style={{paddingTop: "90px"}}>
                    { this.state.authenticateOpen &&
                        <div className="authentication-info">
                            <p>
                                NetApp Cloud Central uses OAUTH2 for authentication. Explanation pending....
                            </p>
                            <textarea placeholder="paste JWT token here" style={{width: "97%", border: "1px solid black"}}>

                            </textarea>
                            <button className="close-login" onClick={() => this.setState({authenticateOpen: false})}>Close</button>
                        </div>
                    }
                    <Errors/>
                    <Row className="information-container">
                        <Col mobile={12}>
                            { info.count() ? (
                                <Info info={ info } url={ url } host={ host } basePath={ basePath } externalDocs={externalDocs} getComponent={getComponent}/>
                            ) : null }
                        </Col>
                    </Row>
                    { schemes && schemes.size || securityDefinitions ? (
                        <div className="scheme-container">
                            <Col className="schemes wrapper" mobile={12}>
                                { schemes && schemes.size ? (
                                    <Schemes
                                        currentScheme={specSelectors.operationScheme()}
                                        schemes={ schemes }
                                        specActions={ specActions } />
                                ) : null }

                                { securityDefinitions ? (
                                    <AuthorizeBtn />
                                ) : null }
                            </Col>
                        </div>
                    ) : null }

                    { servers && servers.size ? (
                        <div className="global-server-container" ref={(el) => this.props.integrator.setServerEl(el)}>
                            <Col className="servers wrapper" mobile={12}>
                                <span className="servers-title">Server</span>
                                <Servers
                                    servers={servers}
                                    currentServer={oas3Selectors.selectedServer()}
                                    setSelectedServer={oas3Actions.setSelectedServer}
                                    setServerVariableValue={oas3Actions.setServerVariableValue}
                                    getServerVariable={oas3Selectors.serverVariableValue}
                                    getEffectiveServerValue={oas3Selectors.serverEffectiveValue}
                                />
                            </Col>
                        </div>

                    ) : null}

                    {
                        filter === null || filter === false ? null :
                            <div className="filter-container">
                                <Col className="filter wrapper" mobile={12}>
                                    <input className="operation-filter-input" placeholder="Filter by tag" type="text" onChange={this.onFilterChange} value={filter === true || filter === "true" ? "" : filter} disabled={isLoading} style={inputStyle} />
                                </Col>
                            </div>
                    }

                    <Row>
                        <Col mobile={12} desktop={12} >
                            <Operations/>
                        </Col>
                    </Row>
                    <Row>
                        <Col mobile={12} desktop={12} >
                            <Models/>
                        </Col>
                    </Row>
                </div>
            </div>
        )
    }
}