const AWS = require('aws-sdk');

AWS.config.update({ region: 'us-east-1' });
AWS.config.setPromisesDependency(require('bluebird'));

const cloudWatchLogs = new AWS.CloudWatchLogs();


const getAllLogGroups = () => {
    const getLogGroupsRecursive = nextToken => {
        const params = {
            limit: 50,
            nextToken,
            logGroupNamePrefix: `/aws/lambda/portal-backend-${process.env.stage}`
        };

        return cloudWatchLogs.describeLogGroups(params).promise().then(({ newNextToken, logGroups }) => {
            if (newNextToken) {
                return getLogGroupsRecursive(newNextToken).then(nextPayload => logGroups.concat(nextPayload));
            }
            return logGroups;
        });
    };

    return getLogGroupsRecursive();
};

const ensureFilterForGroup = ({ logGroupName }) => cloudWatchLogs.describeSubscriptionFilters({ logGroupName }).promise().then(({ subscriptionFilters }) => {
    if (subscriptionFilters.length > 0 || logGroupName.endsWith("kinesisLogStreamPusher")) { return Promise.resolve(); }

    const params = {
        destinationArn: `arn:aws:kinesis:us-east-1:055518636490:stream/portal-backend-${process.env.stage}-logStream`,
        filterName: "kinesisFilter",
        filterPattern: "",
        logGroupName,
        roleArn: `arn:aws:iam::055518636490:role/portal-backend-${process.env.stage}-CloudWatchToKinesisRole`
    };

    return cloudWatchLogs.putSubscriptionFilter(params).promise().catch(err => {
        console.log(`Failed to put subscription filter for ${logGroupName}`);
        console.log(err);
        throw err;
    });
});

getAllLogGroups()
    .then(logGroups => Promise.all(logGroups.map(ensureFilterForGroup)))
    .catch(err => {
        console.log("Failed to execute post deploy cloud-watch script");
        console.log(err);
        process.exit(1);
    });
