const axios = require('axios');
const bodybuilder = require('bodybuilder');
const program = require("commander");
const { sendInternalEmail } = require('./../utils/internal-email');
const { internalGalOnly } = require("./../consts");
const { refreshToken } = require("./getToken");

const KIBANA_URL = process.env.KIBANA_PROXY_URL;
const ENDPOINT = "path=elasticsearch-log-*%2F_search&method=POST";

program
    .description("Run the script with client ID and refresh token to monitor the amount of errors in elasticsearch.")
    .option("-c, --client-id [client-id]", "Auth0 client-id")
    .option("-t, --refresh-token [refresh-token]", "Auth0 refresh-token")
    .parse(process.argv);

const logQuery = () =>
    bodybuilder()
        .query('match_phrase', 'message', 'ERROR')
        .query('range', '@timestamp', { gte: "now-1d/d" })
        .build();

const performQuery = async (query, cookie) => axios.request({
    url: `${KIBANA_URL}?${ENDPOINT}`,
    method: "post",
    headers: {
        "content-type": "application/json",
        cookie,
        "kbn-version": "6.1.1",
        withCredentials: true
    },
    data: query
})
    .then(res => res.data.hits.total)
    .then(errors => {
        console.log(`The total number of errors in the past day is ${errors}`);
        if (errors > 10) {
            sendInternalEmail("Elasticsearch Monitoring Alert", `Elasticsearch has produced ${errors} errors in the past day in ${process.env.stage}.`, internalGalOnly);
        }
    });

const getErrors = async () => {
    const query = logQuery();
    const cookie = await refreshToken(program.clientId, program.refreshToken, false);
    performQuery(query, cookie)
        .catch(async err => {
            if (err.response.status === 401) {
                console.log("Access denied. Refreshing token...");
                const forcedCookie = await refreshToken(program.clientId, program.refreshToken, true);
                await performQuery(query, forcedCookie)
                    .catch(error => console.log(error));
            } else {
                console.log(err);
            }
        });
};

getErrors();
