const nock = require('nock');
const sinon = require('sinon');
const mockAWS = require('aws-sdk-mock');

const entry = require("./connection");
const { authAccount } = require("./../auth-utils");

const nockBase = nock(`https://${authAccount.domain}`);

beforeEach(() => {
    nockBase
        .post('/oauth/token')
        .reply(200, { access_token: "mock-access-token" });
});

afterEach(() => {
    mockAWS.restore();
});

describe("get-users-occms-ids-by-users-ids", () => {
    it("should work", () => {
        const batchGetSpy = sinon.spy((params, callback) => {
            callback(null, {
                Responses: {
                    [`${process.env.userInfoTable}`]: [
                        {
                            userId: "user1",
                            associatedOccms: { values: ["occm-client-1", "occm-client-2", "occm-client-3"] }
                        },
                        {
                            userId: "user2",
                            associatedOccms: { values: ["occm-client-4", "occm-client-5", "occm-client-6"] }
                        }
                    ]
                }
            });
        });
        mockAWS.mock('DynamoDB.DocumentClient', 'batchGet', batchGetSpy);

        const promise = entry.getUsersOccmsIdsByUsersIds(({ usersIds: ["user1", "user2"] }));

        return expect(promise).resolves.toEqual(["occm-client-1", "occm-client-2", "occm-client-3", "occm-client-4", "occm-client-5", "occm-client-6"]);
    });

    it("should handle duplicate occmIds between users", () => {
        const batchGetSpy = sinon.spy((params, callback) => {
            callback(null, {
                Responses: {
                    [`${process.env.userInfoTable}`]: [
                        {
                            userId: "user1",
                            associatedOccms: { values: ["occm-client-1", "occm-client-2", "occm-client-3"] }
                        },
                        {
                            userId: "user2",
                            associatedOccms: { values: ["occm-client-2", "occm-client-3", "occm-client-4"] }
                        }
                    ]
                }
            });
        });
        mockAWS.mock('DynamoDB.DocumentClient', 'batchGet', batchGetSpy);

        const promise = entry.getUsersOccmsIdsByUsersIds(({ usersIds: ["user1", "user2"] }));

        return expect(promise).resolves.toEqual(["occm-client-1", "occm-client-2", "occm-client-3", "occm-client-4"]);
    });
});
