const _ = require("lodash");
const Promise = require("bluebird");
const { promiseInspect } = require("../utils");

const totalPerAccount = resources => resources.reduce((total, resource) => total + resource.val, 0);

const totalPerSubscription = accounts => {
    console.log(`Calculating hourly charge for ${JSON.stringify(accounts)}`);
    // eslint-disable-next-line no-shadow
    return accounts.reduce(({ accumulatedVal, accounts }, account) => {
        const sumPerAccount = totalPerAccount(account.resources);
        accounts.push({ ...account, totalVal: sumPerAccount });
        return {
            accumulatedVal: accumulatedVal + sumPerAccount,
            accounts
        };
    }, { accumulatedVal: 0, accounts: [] });
};

const convertToChargesPerAccount = hourlyCharge => _.map(hourlyCharge.accounts, account => ({
    mergedId: `${hourlyCharge.subscriptionId}-${hourlyCharge.dimension}-${account.accountId}`,
    ..._.pick(hourlyCharge, ['customerIdentifier', 'subscriptionId', 'cloudProvider', 'dimension', 'productCode', 'serviceName', 'timestamp']),
    accountId: account.accountId,
    resources: account.resources,
    totalVal: account.totalVal
}));

const resolveSubscription = get => subscriptionId => promiseInspect(get(subscriptionId));

const saveHourlyCharge = save => charge => promiseInspect(save(charge));

const updateHourlyChargeStatus = update => charge => promiseInspect(update(charge));

const processMeteringResponse = (enhancedChargeBatch, reportResponse) => {
    console.log(`Processing response for batch: ${JSON.stringify(enhancedChargeBatch)}`);
    console.log(`In metering response: ${JSON.stringify(reportResponse)}`);
    return _.map(enhancedChargeBatch, charge => {
        if (reportResponse.status === "rejected") {
            return { ...charge, chargingStatus: false };
        }
        const processedMeteringResponse = _.find(reportResponse.value.Results, {
            UsageRecord: {
                Quantity: charge.accumulatedVal,
                Timestamp: charge.timestamp,
                Dimension: charge.dimension,
                CustomerIdentifier: charge.customerIdentifier
            }
        });
        if (!processedMeteringResponse) {
            console.log(`Critical Error!!! Metering response was not processed for ${charge}`);
            return { ...charge, chargingStatus: false };
        }
        return { ...charge, chargingStatus: (processedMeteringResponse.Status === "Success") };
    });
};

const reportMetering = report => enhancedHourlyCharges => {
    const groupedByProduct = _.groupBy(enhancedHourlyCharges, 'productCode');
    console.log(`Performing metering for: ${JSON.stringify(groupedByProduct)}`);
    return Promise.map(_.keys(groupedByProduct), product => {
        console.log(`Metering product: ${product}`);
        const enhancedChargeBatches = _.chunk(groupedByProduct[product], 25);
        return Promise.map(enhancedChargeBatches, async enhancedChargeBatch => {
            const usages = _.map(enhancedChargeBatch, enhancedCharge => ({
                CustomerIdentifier: enhancedCharge.customerIdentifier,
                Dimension: enhancedCharge.dimension,
                Quantity: enhancedCharge.accumulatedVal,
                Timestamp: enhancedCharge.timestamp
            }));
            console.log(`Metering batch: ${JSON.stringify(usages)}`);
            const reportResponse = await promiseInspect(report(product, usages));
            return processMeteringResponse(enhancedChargeBatch, reportResponse);
        }, { concurrency: 1 });
    }, { concurrency: 1 })
        .then(response => _.flatMapDeep(response));
};

exports.totalPerAccount = totalPerAccount;
exports.totalPerSubscription = totalPerSubscription;
exports.convertToChargesPerAccount = convertToChargesPerAccount;
exports.resolveSubscription = resolveSubscription;
exports.saveHourlyCharge = saveHourlyCharge;
exports.updateHourlyChargeStatus = updateHourlyChargeStatus;
exports.reportMetering = reportMetering;
exports.processMeteringResponse = processMeteringResponse;
