const AWS = require('aws-sdk/index');
const _ = require("lodash");

AWS.config.setPromisesDependency(require('bluebird'));

const marketplaceMetering = new AWS.MarketplaceMetering({ region: 'us-east-1', accessKeyId: process.env.sellerAccessKey, secretAccessKey: process.env.sellerSecretKey });

// const commonResponses = [
//     "TimestampOutOfBoundsException: Timestamp 2019-04-29T16:43:43.834Z is out of allowed range",
//     "InvalidCustomerIdentifierException: An invalid customer identifier was specified: YhRWuVafgdg",
//     "InvalidParameterType: Expected params.UsageRecords[0].Timestamp to be a Date object, ISO-8601 string, or a UNIX timestamp",
//     "Success",
//     "DuplicateRecord",
//     "CustomerNotSubscribed"
// ];

// TODO: handle code duplication
const doWithRetry = (retries, asyncFunc) => asyncFunc()
    .catch(error => {
        const { code, statusCode } = error;
        const retry = (
            code === "ThrottlingException"
            || statusCode == 500 // eslint-disable-line eqeqeq
            || statusCode == 503 // eslint-disable-line eqeqeq
        ) && (retries < process.env.retries);
        console.log(`Error: ${error} \nNumber or retries: ${retries} \nNeed to retry? ${retry}`);
        if (!retry) {
            return Promise.reject(error);
        }
        return Promise.delay(process.env.intervalMillisec * (retries + 1))
            .then(() => doWithRetry(retries + 1, asyncFunc));
    });

const reportMetering = (productCode, usageRecords) => {
    const params = {
        ProductCode: productCode,
        UsageRecords: usageRecords
    };
    // TODO: change code to include restriction on the amount of retries
    return doWithRetry(0, () => marketplaceMetering.batchMeterUsage(params).promise())
        .then(response => {
            if (!_.isEmpty(response.UnprocessedRecords)) {
                console.log(`Not all batch was processed, retrying again`);
                return reportMetering(productCode, usageRecords);
            }
            return response;
        });
};

module.exports.reportMetering = reportMetering;
