const Joi = require("joi");

exports.validateHourlyChargeRequest = requestBody => {
    const resourcesSchema = Joi.object().keys({
        resourceId: Joi.string().required(),
        val: Joi.number().required()
    }).length(2);
    const accountSchema = Joi.object().keys({
        accountId: Joi.string().required(),
        resources: Joi.array().items(resourcesSchema).required()
    });
    const bodySchema = Joi.array().items(Joi.object().keys({
        subscriptionId: Joi.string().required(),
        dimension: Joi.string().required(),
        timestamp: Joi.date().iso().required(),
        accounts: Joi.array().items(accountSchema).required()
    }).length(4));
    return new Promise((resolve, reject) => {
        Joi.validate(requestBody, bodySchema, err => {
            if (err) {
                console.log(err);
                reject(err);
            }
            resolve(true);
        });
    });
};

exports.validateAccumulatedChargePerAccountSchema = accumulatedCharges => {
    const resourcesSchema = Joi.object().keys({
        resourceId: Joi.string().required(),
        val: Joi.number().required()
    }).length(2);
    const bodySchema = Joi.array().items(Joi.object().keys({
        mergedId: Joi.string().required(),
        customerIdentifier: Joi.string().required(),
        subscriptionId: Joi.string().required(),
        accountId: Joi.string().required(),
        resources: Joi.array().items(resourcesSchema).required(),
        totalVal: Joi.number().required(),
        dimension: Joi.string().required(),
        timestamp: Joi.date().iso().required(),
        productCode: Joi.string().required(),
        cloudProvider: Joi.string().required(),
        serviceName: Joi.string().required()
    }).length(11));
    return new Promise((resolve, reject) => {
        Joi.validate(accumulatedCharges, bodySchema, err => {
            if (err) {
                console.log(err);
                reject(err);
            }
            resolve(true);
        });
    });
};

exports.validateUsagesPerProduct = usagesPerProduct => {
    const usageSchema = Joi.object().keys({
        CustomerIdentifier: Joi.string().required(),
        Dimension: Joi.string().required(),
        Quantity: Joi.number().required(),
        Timestamp: Joi.date().iso().required()
    }).length(4);
    const productUsagesSchema = Joi.object().keys({
        productCode: Joi.string().required(),
        usages: Joi.array().items(usageSchema).required()
    }).length(2);
    const bodySchema = Joi.array().items(productUsagesSchema).required();
    return new Promise((resolve, reject) => {
        Joi.validate(usagesPerProduct, bodySchema, err => {
            if (err) {
                console.log(err);
                reject(err);
            }
            resolve(true);
        });
    });
};
