const Promise = require("bluebird");
const { doWithRetry } = require("../src/services/database");

describe('doWithRetry', () => {
    test('given error that requires retry, and a function that results in resolved promise, retry and returns the resolved value', async () => {
        const mockFunc = jest.fn(() => Promise.resolve(7));
        await expect(doWithRetry(0, mockFunc)).resolves.toEqual(7);
        expect(mockFunc.mock.calls.length).toBe(1);
    });
    test('given error that does not requires retry, does not retry and returns promise reject with the error argument', async () => {
        // eslint-disable-next-line prefer-promise-reject-errors
        const mockFunc = jest.fn(() => Promise.reject("bla bla error"));
        await expect(doWithRetry(0, mockFunc)).rejects.toEqual("bla bla error");
        expect(mockFunc.mock.calls.length).toBe(1);
    });
    test('given error that requires retries and a function that results in rejected promise that does require retry, retries in growing gaps and returns rejected promise', async () => {
        jest.setTimeout(20000);
        // eslint-disable-next-line prefer-promise-reject-errors
        const mockFunc = jest.fn(() => Promise.reject({ statusCode: 500 }));
        await expect(doWithRetry(0, mockFunc)).rejects.toEqual({ statusCode: 500 });
        expect(mockFunc.mock.calls.length).toBe(Number(process.env.retries) + 1);
    });
});
