const { validateHourlyChargeRequest, validateAccumulatedChargePerAccountSchema, validateUsagesPerProduct } = require("../src/services/validator");
const requestBodyMock = require("./data-mocks/validRequest");
const badRequestResourceMock = require("./data-mocks/badRequestInvalidResourc");
const badRequestAccountMock = require("./data-mocks/badRequestinvalidAccount");
const accumulatedChargeMock = require("./data-mocks/validAccumulatedCharge");
const invalidAccumulatedChargeMock = require("./data-mocks/invalidAccumulatedCharge");
const validUsagesPerProductMock = require("./data-mocks/validUsagesPerProduct");
const invalidUsagesPerProductMock = require("./data-mocks/invalidUsagesPerProduct");

describe('validateRequestBody', () => {
    test('given a structurally valid body return true', () => expect(validateHourlyChargeRequest(requestBodyMock)).resolves.toBe(true));
    test('given a structurally invalid resource scheme return error', () => {
        expect.assertions(1);
        return validateHourlyChargeRequest(badRequestResourceMock)
            .catch(err => {
                expect(err.details[0].message).toEqual(`"resourceId" is required`);
            });
    });
    test('given a structurally invalid account scheme return error', () => {
        expect.assertions(1);
        return validateHourlyChargeRequest(badRequestAccountMock)
            .catch(err => {
                expect(err.details[0].message).toEqual(`"resources" is required`);
            });
    });
});

describe('validateAccumulatedChargePerAccountSchema', () => {
    test('given a structurally valid array of charges per account return true', () => expect(validateAccumulatedChargePerAccountSchema(accumulatedChargeMock)).resolves.toBe(true));
    test('given a structurally invalid array of charges per account return error', () => {
        expect.assertions(1);
        return validateAccumulatedChargePerAccountSchema(invalidAccumulatedChargeMock)
            .catch(err => {
                expect(err.details[0].message).toEqual(`"customerIdentifier" is required`);
            });
    });
});

describe('validateUsagesPerProduct', () => {
    test('given a structurally valid array of usages per product return true', () => expect(validateUsagesPerProduct(validUsagesPerProductMock)).resolves.toBe(true));
    test('given a structurally invalid array of usages per product return error', () => {
        expect.assertions(1);
        return validateUsagesPerProduct(invalidUsagesPerProductMock)
            .catch(err => {
                expect(err.details[0].message).toEqual(`"productCode" is required`);
            });
    });
});
