import React, { Component } from 'react';
import ReactDOM from 'react-dom';
import './Widget.scss';
import className from "classnames";
import ReactCSSTransitionGroup from 'react-addons-css-transition-group';
import { ReactComponent as CloudVolumesServiceLogo } from 'ui-components/src/images/netapp-services/ic-cvs.svg';
import { ReactComponent as CloudVolumesOntap } from 'ui-components/src/images/netapp-services/ic-cvo.svg';
import { ReactComponent as CloudSyncLogo } from 'ui-components/src/images/netapp-services/ic-cloud-sync.svg';
import { ReactComponent as SaaSBackupLogo } from 'ui-components/src/images/netapp-services/ic-saas-backup.svg';
import { ReactComponent as OCILogo } from 'ui-components/src/images/netapp-services/ic-cloud-insights.svg';
import { ReactComponent as CloudSecureLogo } from 'ui-components/src/images/netapp-services/ic-cloud-sentry.svg';
import { ReactComponent as KubernetesServiceLogo } from 'ui-components/src/images/netapp-services/ic-kubernetes.svg';
import { ReactComponent as CloudTieringLogo } from 'ui-components/src/images/netapp-services/ic-cloud-tiering.svg';
import { ReactComponent as CloudBackupLogo } from 'ui-components/src/images/netapp-services/ic-cloud-backup.svg';
import { ReactComponent as LinkLogo } from './images/ic-goto.svg';
import queryString from "query-string";
import axios from 'axios';
import { Scrollbars } from 'react-custom-scrollbars';

const auth0 = require('auth0-js');
const Auth = require('./Auth.js').default;
window.auth0 = auth0;

//Code from here: https://stackoverflow.com/questions/18338890/are-there-any-sha-256-javascript-implementations-that-are-generally-considered-t
async function sha256(message) {
    // encode as UTF-8
    const msgBuffer = new TextEncoder('utf-8').encode(message);

    // hash the message
    const hashBuffer = await crypto.subtle.digest('SHA-256', msgBuffer);

    // convert ArrayBuffer to Array
    const hashArray = Array.from(new Uint8Array(hashBuffer));

    // convert bytes to hex string
    return hashArray.map(b => ('00' + b.toString(16)).slice(-2)).join('');
}

async function getUserIdForGoogleAnalytics(userId) {
    //For users with federated identity, encrypt their username to not have plain user data in Google analytics.
    //crypto.subtle API is not available on unsecured locations, such as developing on local machines, so in
    //these cases we just use 'developer-local' as user id.
    if (!crypto.subtle) {
        return 'developer-local';
    } else if (userId.startsWith('auth0')) {
        return userId;
    } else {
        return sha256(userId);
    }
}

function hexToRGB(hex, modifier) {
    const r = parseInt(hex.slice(1, 3), 16) * modifier,
        g = parseInt(hex.slice(3, 5), 16)* modifier,
        b = parseInt(hex.slice(5, 7), 16)* modifier;

    return `${r}, ${g}, ${b}`;
}

const alwaysEnabledFeatures = (process.env.REACT_APP_FEATURES || "").split(";");
const getFeatureStatus = (key, userId) => alwaysEnabledFeatures.includes(key) || localStorage.getItem(`portal.feature.${key}.${userId}`) === "true";

const services = [
    {
        Logo: CloudVolumesServiceLogo,
        key: "cloud-volumes",
        title: "Cloud Volumes Service",
        href: process.env.REACT_APP_CLOUD_VOLUMES_SERVICE_AWS_MARKETING_URL
    },
    {
        Logo: CloudVolumesOntap,
        key: "ontap-cloud",
        title: "Cloud Volumes ONTAP",
        href: process.env.REACT_APP_ONTAP_CLOUD_MARKETING_URL
    },
    {
        Logo: KubernetesServiceLogo,
        key: "kubernetes",
        title: "NetApp Kubernetes Service",
        href: process.env.REACT_APP_KUBERNETES_SERVICE_BASE_URL
    },
    {
        Logo: OCILogo,
        key: "oci",
        title: "Cloud Insights",
        href: process.env.REACT_APP_OCI_LINK_URL
    },
    {
        Logo: CloudSyncLogo,
        key: "cloud-sync",
        title: "Cloud Sync",
        href: process.env.REACT_APP_CLOUD_SYNC_BASE_URL
    },
    {
        Logo: SaaSBackupLogo,
        key: "cloud-control",
        title: "SaaS Backup",
        href: process.env.REACT_APP_SAAS_BACKUP_BASE_URL
    },
    {
        Logo: CloudSecureLogo,
        key: "contrail",
        title: "Cloud Secure",
        href: process.env.REACT_APP_CLOUD_SECURE_MARKETING_URL
    },
    {
        Logo: CloudTieringLogo,
        key: "cloud-tiering",
        title: "Cloud Tiering",
        href: process.env.REACT_APP_CLOUD_TIERING_BASE_URL
    },
    {
        Logo: CloudBackupLogo,
        key: "cloud-backup",
        title: "Cloud Backup Service",
        href: process.env.REACT_APP_CLOUD_BACKUP_MARKETING_URL
    }

];

let parentOrigin = null;

let currentService = null;
export default class Widget extends Component {
    constructor(props){
        super(props);
        const parsed = queryString.parse(window.location.search);
        currentService = parsed.service;
        const headerHeight = parsed.headerHeight || "71px";
        const primaryColor = parsed.primaryColor;
        const fixRight = parsed.fixRight === "true";
        const disableHoverEffect = parsed.disableHoverEffect === "true";
        this.state = {attemptingSso: true, services: [], menuOpen: false, menuStateUpdateTime: new Date().valueOf(), headerHeight, fixRight, disableHoverEffect};

        if(currentService === "system-manager") {
            document.getElementById("baseTarget").setAttribute("target", "_blank");
        }

        this.auth = new Auth({
            clientID: window.__auth__.clientId,
            domain: window.__auth__.domain,
            audience: window.__auth__.audience
        });

        const loginSuccess = (authResult) => {
            if(authResult.idTokenPayload){
                getUserIdForGoogleAnalytics(authResult.idTokenPayload.sub)
                    .then(userId => {
                        window.ga('set', 'userId', userId)
                    });

                if(authResult.idTokenPayload['http://cloud.netapp.com/internal'] === "NetAppTest" ) {
                    console.log("Analytics Disabled for Test Account");
                    window['ga-disable-UA-115286337-1'] = true;
                } else if (authResult.idTokenPayload['http://cloud.netapp.com/internal']) {
                    window.ga('set', 'dimension1', authResult.idTokenPayload['http://cloud.netapp.com/internal']);
                }
            }

            window.ga('send', {
                hitType: 'event',
                eventCategory: 'WidgetLoad',
                eventAction: "Load",
                eventLabel: currentService
            });
            axios.defaults.baseURL=process.env.REACT_APP_PORTAL_BACKEND_BASE_URL;
            axios.defaults.headers.common['Authorization'] = `Bearer ${authResult.accessToken}`;
            this.setState({occms: {loading: true}, authenticated: true, attemptingSso: false, auth: authResult.idTokenPayload, userId: authResult.idTokenPayload.sub});
            axios.get("/occm/list-occms")
                .then(({data}) => loadOccms(data.occms.filter(occm => occm.primaryCallbackUri && occm.occmName)),
                    () => {
                        this.setState({occms: {error: true}})
                    });

            setTimeout(() => {
                this.auth.refreshSso(null, null, true).then(loginSuccess, loginFail);
            }, authResult.expiresIn * 1000 - 10000);
        };

        const loginFail = (() => {
            window.ga('send', {
                hitType: 'event',
                eventCategory: 'WidgetLoad',
                eventAction: "Load",
                eventLabel: currentService
            });
            this.setState({authenticated: false, attemptingSso: false})
        });

        this.auth.refreshSso(null, null, true).then(loginSuccess, loginFail);

        const style = window.document.createElement('style');
        style.type = 'text/css';
        style.innerHTML = `.portal-widget-button { height: ${this.state.headerHeight}; }
        .invisible-closer { height: ${this.state.headerHeight}; }
          .portal-widget-button button { background-color: rgba(${hexToRGB(primaryColor, 1)}, 1); }
          .portal-widget-button button:hover { background-color: rgba(${hexToRGB(primaryColor, 0.9)}, 1); }
          .portal-widget-container.menu-open .portal-widget-button button div[class^='a'] { background-color: ${primaryColor}; }
          .portal-widget-menu {
            height: calc(100% - ${this.state.headerHeight});
            top: ${this.state.headerHeight};
           }
          `;
        window.document.head.appendChild(style);

        window.addEventListener("message", (event) =>
        {
            if(event.data.target === "portal-menu-widget"){
                if(event.data.message === "menu"){
                    this.setMenuOpenVal.bind(this)(event.data.menuOpen);
                } else if(event.data.message === "load-ack"){
                    const parent = ReactDOM.findDOMNode(this);
                    const button = parent.children[1];
                    button.style.width = event.data.width;
                    parentOrigin = removeTrailingSlash(event.data.parentOrigin);
                    this.setState({portalUrl: process.env.REACT_APP_PORTAL_FRONTEND_BASE_URL, services: services.filter(service => service.key === "ontap-cloud" ? true : service.key !== currentService)});
                }
            }
        }, false);

        const loadOccms = (occms) => {
            this.setState({occms});
            const style = window.document.createElement('style');
            style.type = 'text/css';
            style.innerHTML = `
                       .occms-enter{
                           transition: all 0.2s linear;
                            height: 0;
                       }

                      .occms-enter-active{
                            height: ${83 + (occms.length - 1)*51}px;
                      } 
                       
                      .occms-leave{
                          transition: all 0.2s linear;
                            height: ${83 + (occms.length - 1)*51}px;
                       }

                      .occms-leave-active{
                            height: 0;
                      }
                    `;
            window.document.head.appendChild(style);
        }
    }

    componentDidMount() {
        setTimeout(() => {
            if(document.readyState === "complete"){
                window.parent.postMessage({message: "loaded"}, "*");
            } else {
                document.addEventListener('readystatechange', () => {
                    if(document.readyState === "complete") {
                        window.parent.postMessage({message: "loaded"}, "*");
                    }
                }, false);
            }
        });
    }

    setMenuOpenVal(menuOpen){
        const stateTimeDiff = new Date().valueOf() - this.state.menuStateUpdateTime;
        window.ga('send', {
            hitType: 'event',
            eventCategory: 'WidgetMenu',
            eventAction: menuOpen ? "Open" : "Close",
            eventLabel: currentService,
            eventValue: stateTimeDiff
        });

        this.setState({menuOpen, menuStateUpdateTime: new Date().valueOf()});
        window.parent.postMessage({message: "set-menu", menuOpen}, "*");
    }

    toggleMenu() {
        this.setMenuOpenVal.bind(this)(!this.state.menuOpen);
    }

    linkClicked() {
        this.setMenuOpenVal(false);
    }

    static track(service){
        window.ga('send', {
            hitType: 'event',
            eventCategory: 'WidgetLink',
            eventAction: 'Click',
            eventLabel: service
        });
    }


    render() {
        return (
            <div className={className("portal-widget-container", {"no-n": this.state.disableHoverEffect, fixLeft: !this.state.fixRight, fixRight: this.state.fixRight, "menu-open": this.state.menuOpen})}>
                <div className="invisible-closer" onClick={() => this.setMenuOpenVal.bind(this)(false)} />

                <div className="portal-widget-button">
                    <button onClick={this.toggleMenu.bind(this)}>
                        {[...new Array(9)].map((x, i) =>
                            <div className={'a'+i} key={i}/>
                        )}
                        <div className={className("something-new-indicator", {active: this.state.indicateSomethingNew})}>
                            <div className="a"/>
                            <div className="b"/>
                        </div>
                    </button>
                </div>


                <ReactCSSTransitionGroup
                    transitionName="menu"
                    transitionEnterTimeout={400}
                    transitionLeaveTimeout={400}>
                    {this.state.menuOpen &&
                    <div className="portal-widget-menu" key="menu">
                        <div className="portal-selector" style={{marginRight: "40px", marginTop: "39px"}}>
                            <a href={this.state.portalUrl} onClick={() => {Widget.track('portal')}}>NetApp Cloud Central<LinkLogo/></a>
                        </div>
                        <Scrollbars
                            thumbSize={126}
                            style={{ width: "calc(100% - 15px)", height: "calc(100% - 75px)"}}
                            renderThumbVertical={props => {
                                const style = props.style;
                                return <div {...props} style={{...style, cursor: "pointer", width: "7px", borderRadius: "5px", backgroundColor: "#b7b7b7"}} />
                            }}
                        >
                            {this.state.services.map(({featureFlag, key, href, title, Logo}) =>
                                <div className="service-selector" key={key}>
                                    {key === "ontap-cloud" && <OccmSelector
                                        isLoading={this.state.attemptingSso || (this.state.occms && this.state.occms.loading)}
                                        isError={this.state.occms && this.state.occms.error}
                                        occms={this.state.occms}
                                        isAuthenticated={this.state.authenticated}
                                        href={href}
                                        title={title}
                                        Logo={Logo}
                                    />}

                                    {key !== "ontap-cloud" && (!featureFlag || (this.state.authenticated && getFeatureStatus(featureFlag, this.state.userId))) &&
                                    <a className="service" href={href} onClick={() => {Widget.track(key)}}>
                                        <Logo/>
                                        {title}
                                    </a>}
                                </div>
                            )}
                        </Scrollbars>
                    </div>
                    }
                </ReactCSSTransitionGroup>
            </div>
        );
    }
}

class OccmSelector extends Component {
    constructor(props){
        super(props);
        this.state = {occmOpen: false};
    }

    render() {
        const {isAuthenticated, isLoading, occms, isError, Logo, title, href} = this.props;
        if (isLoading) {
            return (<div className="loading">
                <Logo/>
                {title}
                <span style={{float: "right", fontSize: 11}}>Loading...</span>
            </div>)
        }
        else if (!isAuthenticated || isError || occms.length === 0) {
            return (
                <a className="service" href={href} onClick={() => {Widget.track('ontap-cloud')}}><Logo/>
                    {title}
                </a>
            )
        } else {
            return (
                <div>
                    <button onClick={() => this.setState({occmOpen: !this.state.occmOpen})}>
                        <Logo/>
                        {title}
                        <div className={className("arrow", {open: this.state.occmOpen})}>
                            <div className="lefty"/>
                            <div className="righty"/>
                        </div>
                    </button>
                    <ReactCSSTransitionGroup
                        transitionName="occms"
                        transitionEnterTimeout={200}
                        transitionLeaveTimeout={200}>
                        {this.state.occmOpen &&
                        <div className="animator">
                            <span className="occm-title">Managed by Cloud Manager:</span>
                            <div className="occms-container" key="occms">
                                {occms.map(occm => (
                                    <div key={occm.occm} className="occm-row">
                                        <a href={occm.primaryCallbackUri} target="_parent" onClick={() => {Widget.track('cloud-manager')}} className={className({active: parentOrigin === removeTrailingSlash(occm.primaryCallbackUri), inactive: parentOrigin !== removeTrailingSlash(occm.primaryCallbackUri)})}>
                                            <div className="text-ellipsis">{occm.occmName}</div>
                                            <div className="text-ellipsis">{occm.primaryCallbackUri}</div>
                                            {  parentOrigin === removeTrailingSlash(occm.primaryCallbackUri) &&
                                                <span style={{fontSize: "12px", fontWeight: "bolder", lineHeight: "20px", textAlign: "center", position: "absolute", right: "0px", top: "5px", display: "inline-block", color: "#fff", backgroundColor: "#7db6f9", borderRadius: "5px", width: "70px", height: "20px"}}>Current</span>
                                            }
                                        </a>
                                    </div>
                                ))}
                            </div>
                        </div>
                        }
                    </ReactCSSTransitionGroup>
                </div>
            )
        }
    }
}

const removeTrailingSlash = (str) => {
    const endsWithSlash = str.lastIndexOf("/") === str.length - 1;
    if (endsWithSlash) return str.substring(0, str.length - 1);
    else return str;
};