const puppeteerBrowser = require('./browser').browser;
const testLinkAndCollect = require('./visiting').testLinkAndCollect;
const merge = require('./merge').merge;
const login = require('./browser').login;
const Constants = require('../utils/Constants');
const Promise = require('bluebird');
const _ = require('lodash');
const fs = require('fs');
const path = require('path');

async function run() {
    const browser = await puppeteerBrowser();
    let hubspotCrawl;
    try {
        await login(browser, "https://services.cloud.netapp.com/?redirectToLogin=true");
        hubspotCrawl = await crawl(browser,{url: Constants.websiteUrl, parentUrl: undefined}, process.env.depth);
    } catch (e) {
        console.log("Login failed, did not perform services page crawl");
        process.exit(1);
        hubspotCrawl = {
            visited: [],
            broken: {},
            staging: {},
            puppeteerError: []
        };
    }
    browser.close();
    return hubspotCrawl;
}

const crawl = async (browser, rootHref, maxDepth) => {

    let output = {
        notVisited: [rootHref],
        visited: [],
        broken: {},
        staging: {},
        puppeteerError: []
    };

    let depth = 0;

    while(depth < maxDepth) {
        console.log(`-------------------------------------------`);
        console.log(`IN DEPTH ${depth}`);
        let batchResults = await Promise.map(output.notVisited, newLinkItem => {
            output.visited.push(newLinkItem);
            // testLinkAndCollect both verifies link correctness (staging/broken) and OPTIONALLY collecting additional links from rendered link page.
            // depth < maxDepth - 1 is evaluated to false on deepest crawling iteration (when depth === maxDepth - 1), preventing collecting any new links as requested.
            return testLinkAndCollect(browser, newLinkItem, depth < maxDepth - 1);
        }, {concurrency: 5});
        merge(output, batchResults);
        console.log(`-------------------------------------------`);
        depth++;
    }
    return output;
};

const printResults = (res) => {
    const output = {
        broken: res.broken,
        staging: res.staging
    };
    fs.writeFileSync(path.resolve(__dirname + `/output.json`), JSON.stringify(output));
};

run().then(res => {
    console.log(`HUBSPOT RESULTS:`);
    console.log(`Broken URLs: ${JSON.stringify(res.broken)}`);
    console.log(`Staging URLs: ${JSON.stringify(res.staging)}`);
    console.log(`Error URLs: ${JSON.stringify(res.puppeteerError)}`);
    if(!_.isEmpty(res.broken) || !_.isEmpty(res.staging)) {
        console.log(`Broken / staging links found`);
        printResults(res);
        process.exit(1);
    }
}).catch(console.log);
