const Constants = require('../utils/Constants');
const Initializer = require('../utils/specInitializer');
const jwtDecoder = require('../utils/general-utils').decodeToken;
const _ = require('lodash');
const Promise = require('bluebird');

const { logger, clients } = Initializer('OCCM cleanup script');

const deleteUserOccm = async (userEmail, userPassword) => {
    let userToken;
    let decodedToken;
    let govUserToken;
    let occmList;
    let userInfoDynamo;

    try {
        govUserToken = await clients.auth0Client.getGovernanceUserToken(userEmail, userPassword);
        await clients.governanceClient.deleteAssociatedOccms(govUserToken);
    } catch (e) {
        logger.error(e);
        throw e;
    }

    try {
        userToken = await clients.auth0Client.getCloudCentralUserToken(userEmail, userPassword);
        occmList = await clients.occmClient.listUserOccms(userToken);
        logger.debug(`User's OCCMs from cloud central API: ${JSON.stringify(occmList)}`);
    } catch (e) {
        logger.error(e);
        throw e;
    }

    try {
        decodedToken = jwtDecoder(userToken);
        userInfoDynamo = await clients.dynamodbClient.getUserInfo(decodedToken.sub);
        logger.debug(`User info from dynamo: ${JSON.stringify(userInfoDynamo)}`);
    } catch (e) {
        logger.error(e);
        throw e;
    }

    if(!_.isEmpty(userInfoDynamo)) {
        if(userInfoDynamo.Item && userInfoDynamo.Item.associatedOccms) {
            throw new Error(`OCCMs of ${userEmail} were not deleted properly`);
        }
    }
};

const deassociateUserOccms = async (userEmail, userPassword) => {
    let userToken;
    let occmList;

    try {
        userToken = await clients.auth0Client.getCloudCentralUserToken(userEmail, userPassword);
        occmList = await clients.occmClient.listUserOccms(userToken);
        logger.debug(`User's OCCMs from cloud central API: ${JSON.stringify(occmList.occms)}`);
        Promise.map(occmList.occms, async occm => {
            await clients.occmClient.deassociateSelf(userToken, occm.occm);
        } ,{concurrency: 1});
        occmList = await clients.occmClient.listUserOccms(userToken);
        logger.debug(`User's OCCMs from cloud central API: ${JSON.stringify(occmList.occms)}`);

    } catch (e) {
        logger.error(e);
        throw e;
    }

};

// deleteUserOccm(Constants.testimioUserEmail, Constants.testimioUserPassword)
//     .catch(console.log);

deassociateUserOccms("rony.levari@netapp.com", "Netapp234").catch(console.log);