const Initializer = require('../utils/specInitializer');
const Promise = require('bluebird');
const path = require('path');
const fs = require('fs');

const { logger, clients } = Initializer('OCCM creation script');

const user1 = {email: "occm-test@netapp.com", authId: "auth0|5c28d36990aa9c06123fc086"};

const generateOccms = (user, numOfOccms) => {
    let counter = 0;
    let occms = [];
    const loop = () => {
        return createOccm(user)
            .then(({clientId, clientSecret}) => {
                occms.push({clientId, clientSecret});
                counter++;
                if(counter < numOfOccms) return loop();
                else return Promise.resolve(occms);
            })
            .catch(error => {
                console.log(error);
            });
    };
    return loop();
};

const createOccm = async (user) => {
    const systemId = "occm-scale-system-id";
    const occmName = "occm-scale";
    const redirectURIs = [
        `http://localagent.occm.com`
    ];

    const userToken = await clients.auth0Client.getCloudCentralUserToken(user.email, "Netapp234");
    const { clientId, clientSecret } = await clients.occmClient.serviceRegisterOccm(systemId, occmName, userToken, true);
    const occmToken = await clients.auth0Client.getOccmToken(clientId, clientSecret);
    await clients.occmClient.updateRedirectUris(redirectURIs, occmToken);
    return {clientId, clientSecret};
};

const outputOccms = (user, occms) => {
    logger.info(`Saving data to file`);
    const json = {user, occms};
    fs.writeFileSync(path.resolve(__dirname + `/clients_${user.email}.json`), JSON.stringify(json));
};

generateOccms(user1, 5)
    .then(res => {
        outputOccms(user1, res);
    })
    .catch(logger.info);
