const expect = require('chai').expect;
const AwsConfigClient = require('./AwsConfigClient');
const Constants = require('../Constants');
const EC2Client = require('./EC2Client');
const should = require('chai').should();
const logger = require('../../logger/Logger');

const awsConfig = new AwsConfigClient();
awsConfig.setRegion(Constants.sydney);
const ec2 = new EC2Client(logger);

describe('EC2Client describe functions', async function() {
    it('Should return an array of volumes, snapshots or instances', async function() {
        const instances = await ec2.describeInstances();
        instances.should.be.an('array');
        const volumes = await ec2.describeVolumes();
        volumes.should.be.an('array');
        const  params = {
            OwnerIds: [
                "642991768967"
            ]
        };
        const snapshots = await ec2.describeSnapshots(params);
        snapshots.should.be.an('array');
    });

    it("Should have an additional info in case of AWS exception", async function(){
        try {
            const params = {
                InstanceIds: [
                    "i-03c9daee98261e13a"
                ]
            };
            await ec2.describeInstances(params);
        } catch (e) {
            expect(JSON.stringify(e.extraInfo)).to.equal(JSON.stringify({ invalidInput: { InstanceIds: [ 'i-03c9daee98261e13a' ] } }));
        }

        try {
            await ec2.describeVolumes("bad params");
        } catch (e) {
            expect(JSON.stringify(e.extraInfo)).to.equal(JSON.stringify({ invalidInput: 'bad params' }));
        }

        try {
            await ec2.describeSnapshots("bad params");
        } catch (e) {
            expect(JSON.stringify(e.extraInfo)).to.equal(JSON.stringify({ invalidInput: 'bad params' }));
        }
    });
});