import React from 'react';
import { connect } from 'react-redux';
import querystring from 'query-string';

import styles from "./Accounts.module.scss"
import 'ag-grid-community/dist/styles/ag-grid.css';
import 'ag-grid-community/dist/styles/ag-theme-balham.css';

import accountsManagementMiddleware from "./../../middlewares/featureApis/accountsManagementMiddleware"
import { registerFeature } from "../../middlewares/apiMiddleware";
import { history } from "../../store";
import Loader from "../../Loader";
import AccountsManagementHeader from './AccountsManagementHeader';
import UsersTab from "./UsersTab";
import WorkspacesTab from './WorkspacesTab';
import AgentsTab from './AgentsTab';

registerFeature("ACCOUNTS-MANAGEMENT", accountsManagementMiddleware);


class AccountsManagement extends React.Component {
    constructor(props) {
        super(props);

        const search = querystring.parse(window.location.search);

        if (search.accountId) {
            props.setAccountId({ accountId: search.accountId });
        }

        window.onmessage = function (e) {
            if (e.data.type === 'SET-ACCOUNT-ID') {
                history.replace(`/components/account?accountId=${e.data.accountId}`);
                props.setAccountId(e.data.payload);
            } else if (e.data.type === 'SET-TENANCY-BASE-URL') {
                props.setTenancyBaseUrl(e.data.payload);
            } else if (e.data.type === 'SET-AGENTS-BASE-URL') {
                props.setAgentsBaseUrl(e.data.payload);
            }
        };

        window.top.postMessage({ type: 'accountManagementReady' }, '*');
    }

    closeButtonClicked() {
        if (this.props.currentUserMenu ||
            this.props.currentUserWorkspacesPopUp ||
            this.props.userForRemoval ||
            this.props.userForWorkspacesManagement ||
            this.props.agentForWorkspacesManagement ||
            this.props.addUserOverlayState
        ) this.props.closeAllOverlays();
        else this.props.closeAccountWidget()
    }

    render() {
        return <div className={styles["accounts-management"]}>
            <AccountsManagementHeader closeButtonClicked={() => this.closeButtonClicked()}/>
            <div className={styles["accounts-body"]}>
                {this.props.loadingData && <Loader/>}
                {this.props.accountManagementError &&
                <div className={styles["main-view-error-message"]}>{this.props.accountManagementError}</div>}
                {this.props.activeTab === 'Users' && <UsersTab/>}
                {this.props.activeTab === 'Workspaces' && <WorkspacesTab/>}
                {this.props.activeTab === 'Agents' && <AgentsTab/>}
            </div>
        </div>;
    }
}

const mapStateToProps = state => {
    return {
        accountManagementError: state.accountsManagement.accountManagementError,
        addUserOverlayState: state.accountsManagement.addUserOverlayState,
        agentForWorkspacesManagement: state.accountsManagement.agentForWorkspacesManagement,
        activeTab: state.accountsManagement.activeTab,
        currentUserMenu: state.accountsManagement.currentUserMenu,
        currentUserWorkspacesPopUp: state.accountsManagement.currentUserWorkspacesPopUp,
        loadingData: state.accountsManagement.loadingData,
        userForRemoval: state.accountsManagement.userForRemoval,
        userForWorkspacesManagement: state.accountsManagement.userForWorkspacesManagement
    };
};

const mapDispatchToProps = dispatch => {
    return {
        setTenancyBaseUrl: ({ tenancyBaseUrl }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:SET-TENANCY-BASE-URL",
                payload: { tenancyBaseUrl }
            });
        },
        setAgentsBaseUrl: ({ agentsBaseUrl }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:SET-AGENTS-BASE-URL",
                payload: { agentsBaseUrl }
            });
        },
        setAccountId: ({ accountId }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:SET-ACCOUNT-ID",
                payload: { accountId }
            });
        },
        closeAllOverlays: () => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:CLOSE-ALL-OVERLAYS"
            })
        },
        closeAccountWidget: () => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:CLOSE-ACCOUNT-WIDGET"
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(AccountsManagement)
