import React from 'react';
import { connect } from 'react-redux';
import classNames from "classnames";
import styles from "./Accounts.module.scss"
import { ReactComponent as AccountSettingsIcon } from "ui-components/src/images/monochrome-icons/ic-account-settings.svg";
import { ReactComponent as CloseXIcon } from "ui-components/src/images/monochrome-icons/x-icon.svg";

const AccountsManagementHeader = ({ closeButtonClicked, activeTab, setTab }) => (
    <div className={styles["accounts-header"]}>
        <AccountSettingsIcon/>
        <h3 className={styles["main-title"]}>Account Settings</h3>
        <div className={styles["tabs"]}>
            {['Users', 'Workspaces', 'Agents'].map(tabName =>
                <button key={tabName}
                        onClick={() => setTab({ tabName })}
                        className={classNames(activeTab === tabName ? styles.active : null)}
                        title={tabName}>
                    {tabName}
                </button>
            )}
        </div>
        <button className={styles["close-button"]} onClick={closeButtonClicked}><CloseXIcon/></button>
    </div>);


const mapStateToProps = state => {
    return {
        accountManagementError: state.accountsManagement.accountManagementError,
        activeTab: state.accountsManagement.activeTab,
    };
};

const mapDispatchToProps = dispatch => {
    return {
        setTab: ({ tabName }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:SET-TAB",
                payload: { tabName }
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(AccountsManagementHeader)
