import React from 'react';
import { connect } from 'react-redux';
import { ReactComponent as UserIcon } from "ui-components/src/images/monochrome-icons/ic-user.svg";
import styles from "./Accounts.module.scss"
import buttons from 'ui-components/src/button/button.module.scss';
import Loader from "../../Loader";

const DisassociateUserOverlay = ({ userForRemoval, disassociateUserPrompt, disassociateUser, disassociateUserError, disassociateUserPending }) => (
    <div className={styles["disassociate-user-overlay"]}>
        {disassociateUserPending && <Loader/>}
        <UserIcon/>
        <div className={styles["user-name"]}>{userForRemoval.name}</div>
        <div className={styles["title"]}>Are you sure you want to disassociate this user from this account?</div>
        <div className={styles["button-box"]}>
            <button type="button" className={buttons.cancel} onClick={() => disassociateUserPrompt({})}>Cancel</button>
            <button type="submit" className={buttons.primary}
                    onClick={() => disassociateUser({ associatedUserPublicId: userForRemoval.userPublicId })}>
                Disassociate user
            </button>
        </div>
        {disassociateUserError && <div className={styles["error-message"]}>{disassociateUserError}</div>}
    </div>);

const mapStateToProps = state => {
    return {
        userForRemoval: state.accountsManagement.userForRemoval,
        disassociateUserError: state.accountsManagement.disassociateUserError,
        disassociateUserPending: state.accountsManagement.disassociateUserPending
    };
};

const mapDispatchToProps = dispatch => {
    return {
        disassociateUserPrompt: ({ user }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:DISASSOCIATE-USER-PROMPT",
                payload: user
            })
        },
        disassociateUser: ({ associatedUserPublicId }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:DISASSOCIATE-USER",
                payload: { associatedUserPublicId }
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(DisassociateUserOverlay)
