import React from 'react';
import { connect } from 'react-redux';
import _ from 'lodash'
import classNames from "classnames";

import styles from "./Accounts.module.scss"
import { ReactComponent as WorkspaceIcon } from "ui-components/src/images/2-colors-icons/ic-workspace.svg";
import { ReactComponent as EditPencil } from "ui-components/src/images/monochrome-icons/ic-pencil.svg"
import { ReactComponent as DeleteIcon } from "ui-components/src/images/monochrome-icons/ic-delete.svg"
import { ReactComponent as InlineLoader } from "ui-components/src/images/loaders/inline-loader.svg";

class WorkspacesTab extends React.Component {
    constructor(props) {
        super(props);

        this.state = { workspaceForRenaming: null, workspaceForDeleting: null };
        this.props.accountWorkspaces && this.props.accountWorkspaces.forEach(workspace => {
                this[`${workspace.workspacePublicId}Input`] = React.createRef();
                this.state[`${workspace.workspacePublicId}Input`] = workspace.workspaceName
            }
        );
        this.props.displayError({ errorMessage: null });

        this.addNewInput = React.createRef();
        this.renameButtonClicked = this.renameButtonClicked.bind(this);
        this.deleteButtonClicked = this.deleteButtonClicked.bind(this);
        this.cancelRenameButtonClicked = this.cancelRenameButtonClicked.bind(this);
        this.cancelDeleteButtonClicked = this.cancelDeleteButtonClicked.bind(this);
        this.handleInputName = this.handleInputName.bind(this);
    }

    renameButtonClicked({ workspace }) {
        this.setState({ workspaceForRenaming: workspace }, () => {
            this[`${workspace.workspacePublicId}Input`].current.focus();
        });
    }

    deleteButtonClicked({ workspace }) {
        this.setState({ workspaceForDeleting: workspace });
    }

    cancelRenameButtonClicked({ workspace }) {
        this.props.displayError({ errorMessage: null });
        this.setState({ workspaceForRenaming: null, [`${workspace.workspacePublicId}Input`]: workspace.workspaceName });
    }

    cancelDeleteButtonClicked() {
        this.setState({ workspaceForDeleting: null });
    }

    renameWorkspace({ workspace, event }) {
        event.preventDefault();

        if (WorkspacesTab.isWorkspaceNameValid(this.state[`${workspace.workspacePublicId}Input`])) {
            this.props.editWorkspaceName({ workspace, newName: this.state[`${workspace.workspacePublicId}Input`] });
            this.setState({ workspaceForRenaming: null });
        } else {
            this.props.displayError({errorMessage: 'Please enter a name that contains 1 to 40 alphanumeric characters, underscores, or hyphens.'});
        }
    }

    deleteWorkspace({ workspace }) {
        this.props.deleteWorkspace({ workspace });
        this.setState({ workspaceForDeleting: null });
    }

    handleInputName(event) {
        this.setState({ [event.target.name]: event.target.value });
    }

    toggleCreateNewWorkspace(value) {
        if (!value) {
            this.props.displayError({ errorMessage: null });
        }
        this.setState({ addNew: value }, () => {
            value && this.addNewInput.current.focus();
        });
    }

    static isWorkspaceNameValid(workspaceName) {
        return /^[-_\w]{1,40}$/.test(workspaceName);
    }

    addWorkspace(event) {
        event.preventDefault();
        if (this.state.addNewInput) {
            if (WorkspacesTab.isWorkspaceNameValid(this.state.addNewInput)) {
                this.props.addNewWorkspace({ newName: this.state.addNewInput });
            } else {
                this.props.displayError({ errorMessage: 'Please enter a name that contains 1 to 40 alphanumeric characters, underscores, or hyphens.' });
            }
        }
    }

    newWorkspaceAdded(newWorkspace) {
        this[`${newWorkspace.workspacePublicId}Input`] = React.createRef();
        this.setState({
            [`${newWorkspace.workspacePublicId}Input`]: newWorkspace.workspaceName,
            addNew: false
        });
    }

    componentDidUpdate(prevProps) {
        // Case add workspace success:
        if (!this.props.addNewWorkspacePending && prevProps.addNewWorkspacePending &&
            this.props.accountWorkspaces.length === prevProps.accountWorkspaces.length + 1) {
            const newWorkspace = _.differenceWith(this.props.accountWorkspaces, prevProps.accountWorkspaces, _.isEqual);

            this.newWorkspaceAdded(newWorkspace[0]);
        }
        // Case rename failed:
        if (this.props.failedRenameWorkspace && !prevProps.failedRenameWorkspace) {
            this.renameButtonClicked({ workspace: this.props.failedRenameWorkspace });
        }
    }

    onEscPressed(callback) {
        return event => {
            if (event.keyCode === 27) callback();
        };
    }

    render() {
        return (<div className={styles["workspaces-tab"]}>
            <WorkspaceIcon/>
            <div className={styles["user-name"]}>{this.props.account && this.props.account.accountName}</div>
            <div className={styles["title"]}>Manage Account Workspaces</div>
            {this.props.accountWorkspaces &&
            <button className={styles['add-new-button']}
                    onClick={() => this.toggleCreateNewWorkspace(true)}
                    disabled={this.state.workspaceForDeleting || this.state.workspaceForRenaming}>
                +&nbsp;&nbsp;Add New Workspace
            </button>}
            {this.props.accountWorkspaces && <div className={styles["workspace-cards"]}>
                {this.state.addNew && <form className={styles["workspace-card"]}>
                    <input type="text"
                           name="addNewInput"
                           placeholder="New Workspace Name"
                           ref={this.addNewInput}
                           onChange={this.handleInputName}/>
                    {!this.props.addNewWorkspacePending &&
                    <button type="button" className={classNames(styles["inline-button"], styles["cancel"])}
                            onClick={() => this.toggleCreateNewWorkspace(false)}>
                        Cancel
                    </button>}
                    {!this.props.addNewWorkspacePending &&
                    <button type="submit" className={classNames(styles["inline-button"], styles["submit"])}
                            disabled={!this.state.addNewInput}
                            onClick={(event) => this.addWorkspace(event)}>Add
                    </button>}
                    {this.props.addNewWorkspacePending && <InlineLoader className={styles["inline-loader"]}/>}
                </form>}
                {this.props.accountWorkspaces.map(workspace => {
                    const renaming = _.get(this.state.workspaceForRenaming, 'workspacePublicId') === workspace.workspacePublicId;
                    const deleting = _.get(this.state.workspaceForDeleting, 'workspacePublicId') === workspace.workspacePublicId;
                    const renamePending = this.props.workspaceRenamePending === workspace.workspacePublicId;
                    const deletePending = this.props.workspaceDeletePending === workspace.workspacePublicId;
                    const disableInlineButtons = this.state.workspaceForDeleting || this.state.workspaceForRenaming || this.state.addNew || this.props.workspaceRenamePending || this.props.workspaceDeletePending;
                    const isLastWorkspace = this.props.accountWorkspaces.length === 1;
                    // This is to prevent the input from transitioning from uncontrolled to controlled element when new
                    // workspace is created and the state is not yet updated with the input value:
                    const displayInputElement = !deleting && (renaming || this.state[`${workspace.workspacePublicId}Input`]);

                    return (<form key={workspace.workspacePublicId}
                                  className={styles["workspace-card"]}>
                        {displayInputElement && <input type="text"
                                                       name={`${workspace.workspacePublicId}Input`}
                                                       value={this.state[`${workspace.workspacePublicId}Input`]}
                                                       placeholder="Workspace name"
                                                       disabled={!renaming}
                                                       onKeyUp={this.onEscPressed(() => this.cancelRenameButtonClicked({ workspace }))}
                                                       ref={this[`${workspace.workspacePublicId}Input`]}
                                                       onChange={this.handleInputName}
                                                       title={renaming ? '' : this.state[`${workspace.workspacePublicId}Input`]}/>}
                        {!renaming && !renamePending && !deleting && !deletePending && <button
                            className={styles["inline-button"]}
                            onClick={() => this.deleteButtonClicked({ workspace })}
                            title={isLastWorkspace? "Last workspace cannot be deleted: at least one workspace should exist in account" : "Delete"}
                            disabled={disableInlineButtons || isLastWorkspace}>
                            <DeleteIcon/>
                        </button>}
                        {!renaming && !renamePending && !deleting && !deletePending && <button
                            className={styles["inline-button"]}
                            onClick={() => this.renameButtonClicked({ workspace })}
                            title="Rename"
                            disabled={disableInlineButtons}>
                            <EditPencil/>
                        </button>}
                        {renaming &&
                        <button type="button" className={classNames(styles["inline-button"], styles["cancel"])}
                                onClick={() => this.cancelRenameButtonClicked({ workspace })}>Cancel</button>}
                        {renaming &&
                        <button type="submit" className={classNames(styles["inline-button"], styles["submit"])}
                                disabled={!this.state[`${workspace.workspacePublicId}Input`]}
                                onClick={event => this.renameWorkspace({ event, workspace })}>
                            Rename
                        </button>}
                        {deleting &&
                        <span
                            className={styles["delete-message"]}>Are you sure you want to delete this workspace?</span>}
                        {deleting &&
                        <button type="button" className={classNames(styles["inline-button"], styles["cancel"])}
                                onClick={this.cancelDeleteButtonClicked}>Cancel</button>}
                        {deleting &&
                        <button type="submit" className={classNames(styles["inline-button"], styles["submit"])}
                                onClick={() => this.deleteWorkspace({ workspace })}>Delete</button>}
                        {(renamePending || deletePending) && <InlineLoader className={styles["inline-loader"]}/>}
                    </form>)
                })}
            </div>}
            {this.props.manageWorkspaceError &&
            <div className={styles["error-message"]}>{this.props.manageWorkspaceError}</div>}
        </div>)
    };
}

const mapStateToProps = state => {
    return {
        account: state.accountsManagement.account,
        accountWorkspaces: state.accountsManagement.accountWorkspaces,
        workspaceRenamePending: state.accountsManagement.workspaceRenamePending,
        workspaceDeletePending: state.accountsManagement.workspaceDeletePending,
        addNewWorkspacePending: state.accountsManagement.addNewWorkspacePending,
        manageWorkspaceError: state.accountsManagement.manageWorkspaceError,
        failedRenameWorkspace: state.accountsManagement.failedRenameWorkspace
    };
};

const mapDispatchToProps = dispatch => {
    return {
        editWorkspaceName: ({ workspace, newName }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:EDIT-WORKSPACE-NAME",
                payload: { workspace, newName }
            })
        },
        deleteWorkspace: ({ workspace }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:DELETE-WORKSPACE",
                payload: workspace
            })
        },
        addNewWorkspace: ({ newName }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:ADD-NEW-WORKSPACE",
                payload: { newName }
            })
        },
        displayError: ({ errorMessage }) => {
            dispatch({
                type: "ACCOUNTS-MANAGEMENT:DISPLAY-WORKSPACES-ERROR",
                payload: { errorMessage }
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(WorkspacesTab)