import React from 'react';
import { connect } from 'react-redux';
import { ReactComponent as ProtectionIcon } from 'ui-components/src/images/monochrome-icons/protection-icon.svg';
import { ReactComponent as SavingsIcon } from 'ui-components/src/images/monochrome-icons/savings-icon.svg';
import { DoubleRightChevron, RightChevron } from "./summary-components/Icons";
import SummaryHeader from "./summary-components/SummaryHeader";
import { ReactComponent as NotifyIcon } from 'ui-components/src/images/monochrome-icons/notify-icon.svg';
import ActionButton from "./../widgets/ActionButton";

import Popover from "components/widgets/Popover";
import SalesPitch from "./summary-components/SalesPitch";
import SalesPoints from "./summary-components/SalesPoints";
import { ReactComponent as SnapshotEfficienciesIcon } from './summary-components/snapshot-efficiencies-icon.svg';
import { ReactComponent as StorageEfficienciesIcon } from './summary-components/storage-efficiencies-icon.svg';
import { ReactComponent as DataTieringIcon } from './summary-components/data-tiering-icon.svg';
import { ReactComponent as SnapshotPoliciesIcon } from './summary-components/snapshot-policies-icon.svg';
import { ReactComponent as HighAvailabilityIcon } from './summary-components/high-availability-icon.svg';
import { ReactComponent as DataProtectionIcon } from './summary-components/data-protection-icon.svg';
import DownloadAllCsvLists from "./summary-components/DownloadLists";

const NoResourcesBox = ({startAgain}) => {
    return <div className="empty-notice">
        <div className="icon" style={{'paddingTop': '7px'}}><NotifyIcon/></div>
        <div className="text">
            We couldn't find any volumes or snapshots associated with this account.<br/>
            You can start again with different credentials or region. <ActionButton category="CloudAssessment" label="reset" className="a read-more" onClick={startAgain}>Start Again <RightChevron/></ActionButton>
        </div>
    </div>
};

const leftPoints = [
    {Icon: SnapshotEfficienciesIcon, title: "Snapshot Efficiencies", text:"Efficient storage snapshot and integrated replication to support backup and DR" },
    {Icon: StorageEfficienciesIcon, title: "Storage Efficiencies", text: "Utilize core features of data compression, deduplication and thin provisioning"},
    {Icon: DataTieringIcon, title: "Data Tiering", text: "Allow data to be stored for as low as $0.03 per GB per month on Amazon S3" }];

const rightPoints = [
    { Icon: SnapshotPoliciesIcon, title: "Snapshot Policies", text: "Leverage our automation capabilities to create and delete your snapshots" },
    { Icon: HighAvailabilityIcon, title: "High Availability", text: "With our zero-second RPO, you can be sure that you will never lose data" },
    { Icon: DataProtectionIcon, title: "Data Protection", text: "Seamless failover, failback, restore, and recovery processes that meet minute-level SLAs"}];

const SummaryContainer = ({summary, startAgain, downloadLists}) => {
    const noResourcesInAccount = summary.totalVolumes === 0 && summary.totalRelevantSnapshots === 0;

    return (<div className="summary-container aws">
        <SummaryHeader title="AWS Cloud Assessment" summary={summary} locationLabel="REGION" locationPath="region" volumeLabel="AWS EBS VOLUMES" volumePath="totalVolumes" startAgain={startAgain}/>

        {noResourcesInAccount && <NoResourcesBox startAgain={startAgain}/>}
        {!noResourcesInAccount && (<div className="outcome">
                <div className="savings-outcome">
                    <div className="top">
                        <h3>
                            <SavingsIcon/>
                            Saving Opportunities
                        </h3>
                        <hr/>
                        <span className="outcome-value">{summary.efficiency.f_totalCost}</span>
                        <span className="outcome-title">Total Saving Opportunity (Annual)</span>
                    </div>
                    <div className="bottom" style={{display: "table", padding: "30px 40px 40px 40px", width: "100%"}}>
                        {(summary.unattachedVolumes.length || summary.notAttachedSnapshots.length || '') && <DownloadAllCsvLists onClick={() => downloadLists([{
                            fileName: `NetApp AWS Cloud Assessment - Unattached EBS Volumes`,
                            data: summary.unattachedVolumes
                        }, {
                            fileName: `NetApp AWS Cloud Assessment - Unassociated EBS Snapshots`,
                            data: summary.notAttachedSnapshots
                        }])}/>}
                        <Popover className="info-popover" containerClassName="info-button" component="info">
                            <div><span className="title">Unattached EBS Volumes </span><span>- The annual cost of EBS volumes that are not attached to an EC2 instance.</span></div>
                            <div><span className="title">Unassociated EBS Snapshots </span><span>- The annual cost of EBS snapshots from deleted volumes or EBS snapshots that were copied from another AWS region or account.</span></div>
                        </Popover>
                        <div className="row">
                            <div className="bottom-value">{summary.efficiency.f_unattachedVolumesCount}</div>
                            <div className="bottom-title">Unattached EBS Volumes</div>

                            <div style={{paddingRight: 51}}>
                                <DoubleRightChevron/>
                            </div>

                            <div className="bottom-value">{summary.efficiency.f_unusedVolumesCost}</div>
                            <div className="bottom-title">Saving</div>
                        </div>
                        <div className="row align-bottom">
                            <div className="bottom-value">{summary.efficiency.f_snapshotsWithoutVolumesCount}
                            </div>
                            <div className="bottom-title">Unassociated EBS Snapshots</div>

                            <div style={{paddingRight: 38}}>
                                <DoubleRightChevron/>
                            </div>

                            <div className="bottom-value">{summary.efficiency.f_unusedSnapshotsCost}</div>
                            <div className="bottom-title">Saving</div>
                        </div>
                    </div>
                </div>

                <div className="protection-outcome">
                    <div className="top">
                        <h3>
                            <ProtectionIcon/>
                            Protection Risks <span>(EBS Volumes)</span>
                        </h3>
                        <hr/>
                        <span className="outcome-value">{summary.protection.f_volumesWithoutSnapshotsCount} / {summary.f_totalVolumes}</span>
                        <span className="outcome-title">volumes without EBS Snapshots</span>
                    </div>
                    <div className="bottom" style={{display: "table", padding: "30px 40px 40px 40px", width: "100%"}}>
                        <Popover className="aws-protection info-popover" containerClassName="info-button" component="info">
                            <div><span className="title">Average RPO </span><span>- The average Recovery Point Objective for EBS volumes that have at least one Snapshot, excluding Cloud ONTAP volumes.</span></div>
                            <div><span className="title">Average Number of EBS Snapshots </span><span>- Average number of EBS snapshots for EBS volumes that have at least one snapshot, excluding Cloud ONTAP volumes.</span></div>
                        </Popover>
                        <div className="row">
                            <div>
                                <span className="bottom-value" style={{marginRight: 15}}>{summary.protection.f_averageRPO}</span>
                                <span className="bottom-title">Average RPO</span>
                            </div>
                        </div>
                        <div className="row align-bottom">
                            <div>
                                <span className="bottom-value" style={{marginRight: 15}}>{summary.protection.averageNumberOfSnapshots}</span>
                                <span className="bottom-title">Average Number of EBS Snapshots per volume</span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        )}

        <SalesPoints leftPoints={leftPoints} rightPoints={rightPoints}/>

        <SalesPitch
            title="Maximize your AWS storage with Cloud Volumes"
            serviceName="Cloud Volume Service with AWS"
            provider="AWS"
            cloudVolumesServiceLinkKey="cloudAssessment.summary.startCloudVolumesServiceAws"
            tcoCalculatorLinkKey="cloudAssessment.summary.awsTcoCalculator"
            readMoreLinkKey="cloudAssessment.summary.readMoreCloudVolumesServiceAws"
        />
    </div>)
};

const mapDispatchToProps = dispatch => {
    return {
        startAgain: () => {
            dispatch({
                type: "CLOUD-ASSESSMENT:RESET"
            });
        },
        downloadLists: (dataToDownload) => {
            dispatch({
                type: "CLOUD-ASSESSMENT:AWS-DOWNLOAD-LISTS",
                payload: dataToDownload
            });
        }
    }
};

export default connect(null, mapDispatchToProps)(SummaryContainer);