import React from 'react'
import { connect } from 'react-redux'

import { ReactComponent as ProtectionIcon } from 'ui-components/src/images/monochrome-icons/protection-icon.svg';
import { ReactComponent as SavingsIcon } from 'ui-components/src/images/monochrome-icons/savings-icon.svg';
import {DoubleRightChevron, RightChevron} from "./summary-components/Icons"
import SummaryHeader from "./summary-components/SummaryHeader"

import { ReactComponent as NotifyIcon } from 'ui-components/src/images/monochrome-icons/notify-icon.svg';
import Popover from "components/widgets/Popover"
import SalesPitch from "./summary-components/SalesPitch"
import SalesPoints from "./summary-components/SalesPoints"
import ActionButton from "./../widgets/ActionButton"
import { ReactComponent as SnapshotEfficienciesIcon } from './summary-components/snapshot-efficiencies-icon.svg';
import { ReactComponent as StorageEfficienciesIcon } from './summary-components/storage-efficiencies-icon.svg';
import { ReactComponent as DataTieringIcon } from './summary-components/data-tiering-icon.svg';
import { ReactComponent as SnapshotPoliciesIcon } from './summary-components/snapshot-policies-icon.svg';
import { ReactComponent as DataProtectionIcon } from './summary-components/data-protection-icon.svg';
import DownloadAllCsvLists from "./summary-components/DownloadLists";

const NoResourcesBox = ({startAgain}) => {
    return <div className="empty-notice">
        <div className="icon" style={{'paddingTop': '7px'}}><NotifyIcon/></div>
        <div className="text">
            We couldn't find any disks or snapshots associated with this subscription.<br/>
            Make sure you have the neccessay permissions.<br/>
            You can start again with different subscription or log in with different user account. <ActionButton category="CloudAssessment" label="reset" className="a read-more" onClick={startAgain}>Start Again <RightChevron/></ActionButton>
        </div>
    </div>
};

const leftPoints = [
    {Icon: SnapshotEfficienciesIcon, title: "Snapshot Efficiencies", text:"Efficient storage snapshot and integrated replication to support backup and DR" },
    {Icon: StorageEfficienciesIcon, title: "Storage Efficiencies", text: "Utilize core features of data compression, deduplication and thin provisioning"},
    {Icon: DataTieringIcon, title: "Data Tiering", text: "Allow data to be stored for as low as $0.03 per GB per month on Azure Blob" }];

const rightPoints = [
    { Icon: SnapshotPoliciesIcon, title: "Snapshot Policies", text: "Leverage our automation capabilities to create and delete your snapshots" },
    { Icon: DataProtectionIcon, title: "Data Protection", text: "Seamless failover, failback, restore, and recovery processes that meet minute-level SLAs"}];

const SummaryContainer = ({summary, startAgain, downloadLists}) => {
    const noResourcesInAccount = summary.disksCount === 0 && summary.snapshotsCount === 0;

    return (<div className="summary-container azure">
        <SummaryHeader title="Azure Cloud Assessment" summary={summary} startAgain={startAgain} locationLabel="SUBSCRIPTION" locationPath="subscription" volumeLabel="MANAGED DISKS" volumePath="disksCount"/>

        {noResourcesInAccount && <NoResourcesBox startAgain={startAgain}/>}
        {!noResourcesInAccount && (<div className="outcome">
                <div className="savings-outcome">
                    <div className="top">
                        <h3>
                            <SavingsIcon/>
                            Saving Opportunities
                        </h3>
                        <hr/>
                        <span className="outcome-value">{summary.efficiency.f_totalCost}</span>
                        <span className="outcome-title">Total Saving Opportunity (Annual)</span>
                    </div>
                    <div className="bottom" style={{display: "table", padding: "30px 40px 40px 40px", width: "100%"}}>
                        {(summary.unattachedDisks.length || summary.unassociatedSnapshots.length || '') && <DownloadAllCsvLists onClick={() => downloadLists([{
                            fileName: `NetApp Azure Cloud Assessment - Unattached Disks`,
                            data: summary.unattachedDisks
                        }, {
                            fileName: `NetApp Azure Cloud Assessment - Unassociated Snapshots`,
                            data: summary.unassociatedSnapshots
                        }])}/>}
                        <Popover className="info-popover" containerClassName="info-button" component="info">
                            <div><span className="title">Unattached Managed Disks </span><span>- The annual cost of Managed Disks that are not attached to a VM.</span></div>
                            <div><span className="title">Unassociated Snapshots </span><span>- The annual cost of snapshots from deleted managed disks, estimation based on 65% used capacity.</span></div>
                        </Popover>
                        <div className="row">
                            <div className="bottom-value">{summary.efficiency.f_unattachedDisksCount}</div>
                            <div className="bottom-title">Unattached Disks</div>

                            <div style={{paddingRight: 51}}>
                                <DoubleRightChevron/>
                            </div>

                            <div className="bottom-value">{summary.efficiency.f_unattachedDisksAnnualCost}</div>
                            <div className="bottom-title">Saving</div>
                        </div>
                        <div className="row align-bottom">
                            <div className="bottom-value">{summary.efficiency.f_unassociatedSnapshotsCount}</div>
                            <div className="bottom-title">Unassociated Snapshots</div>

                            <div style={{paddingRight: 38}}>
                                <DoubleRightChevron/>
                            </div>

                            <div className="bottom-value">{summary.efficiency.f_unassociatedSnapshotsAnnualCost}</div>
                            <div className="bottom-title">Saving</div>
                        </div>
                    </div>
                </div>

                <div className="protection-outcome">
                    <div className="top">
                        <h3>
                            <ProtectionIcon/>
                            Protection <span>(Managed Disks)</span>
                        </h3>
                        <hr/>
                        <span className="outcome-value">{summary.protection.f_disksWithoutSnapshotsCount} / {summary.f_disksCount}</span>
                        <span className="outcome-title">disks without Snapshots</span>
                    </div>
                    <div className="bottom" style={{display: "table", padding: "30px 40px 40px 40px", width: "100%"}}>
                        <Popover className="info-popover" containerClassName="info-button" component="info">
                            <div><span className="title">Average RPO </span><span>- The average Recovery Point Objective for Managed Disks that have at least one Snapshot, excluding Cloud ONTAP disks.</span></div>
                            <div><span className="title">Average Snapshots per disk </span><span>- Average number of snapshots for Managed Disks that have at least one snapshot, excluding Cloud ONTAP disks.</span></div>
                        </Popover>
                        <div className="row">
                            <div>
                                <span className="bottom-value" style={{marginRight: 15}}>{summary.protection.f_averageRPO}</span>
                                <span className="bottom-title">Average RPO</span>
                            </div>
                        </div>
                        <div className="row align-bottom">
                            <div>
                                <span className="bottom-value" style={{marginRight: 15}}>{summary.protection.averageNumberOfSnapshots}</span>
                                <span className="bottom-title">Average Snapshots per disk</span>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        )}

        <SalesPoints leftPoints={leftPoints} rightPoints={rightPoints}/>

        <SalesPitch
            title="Maximize your Azure storage with Cloud Volumes"
            provider="Azure"
            serviceName="Azure NetApp Files"
            cloudVolumesServiceLinkKey="cloudAssessment.summary.startCloudVolumesServiceAzure"
            tcoCalculatorLinkKey="cloudAssessment.summary.azureTcoCalculator"
            readMoreLinkKey="cloudAssessment.summary.readMoreCloudVolumesServiceAzure"
        />

    </div>)
};

const mapDispatchToProps = dispatch => {
    return {
        startAgain: () => {
            dispatch({
                type: "CLOUD-ASSESSMENT:RESET"
            });
        },
        downloadLists: (dataToDownload) => {
            dispatch({
                type: "CLOUD-ASSESSMENT:AZURE-DOWNLOAD-LISTS",
                payload: dataToDownload
            });
        }
    }
};

export default connect(null, mapDispatchToProps)(SummaryContainer);