import React from 'react'
import { connect } from 'react-redux'
import { Redirect, Route, Switch, withRouter } from 'react-router-dom'
import _ from 'lodash'
import "./CloudAssessmentView.scss"
import CloudAssessmentViewAws from "./CloudAssessmentViewAws";
import CloudAssessmentChooseCloudProvider from "./CloudAssessmentChooseCloudProvider"
import CloudAssessmentViewAzure from "./CloudAssessmentViewAzure"
import { registerFeature } from './../../middlewares/apiMiddleware';
import cloudAssessmentMiddleware from "./../../middlewares/featureApis/cloudAssessmentMiddleware";
import CloudCentralSecondaryHeader from "../headers/CloudCentralSecondaryHeader";

registerFeature("CLOUD-ASSESSMENT", cloudAssessmentMiddleware);

const mapStateToPropsHeader = state => {
    return {
        stage: state.cloudAssessment.stage
    }
};

const DumbCloudAssessmentHeader = ({ stage }) => {
    if (_.startsWith(stage, "CREDENTIALS")) {
        return <CloudCentralSecondaryHeader title="Cloud Assessment" smartBack={true}/>;
    } else {
        return <div/>
    }
};

const CloudAssessmentHeader = withRouter(connect(mapStateToPropsHeader)(DumbCloudAssessmentHeader));

const CloudAssessmentView = () => {
    return <React.Fragment>
        <CloudAssessmentHeader/>
        <div className="cloud-assessment-view new">
            <Switch>
                <Route path="/cloud-assessment" exact render={() => <CloudAssessmentChooseCloudProvider/>}/>
                <Route path="/cloud-assessment/aws" exact render={() => <CloudAssessmentViewAws/>} />
                <Route path="/cloud-assessment/azure" exact render={() => <CloudAssessmentViewAzure/>}/>
                <Redirect to="/cloud-assessment"/>
            </Switch>
        </div>
    </React.Fragment>
};

export default CloudAssessmentView;

