import React from 'react';
import connect from "react-redux/es/connect/connect";
import DashboardContainer from "./DashboardContainer";
import { STATUS_ERROR, STATUS_SUCCESS } from "../../actions";
import styles from "./Dashboard.module.scss"

import { ReactComponent as CloudVolumesOntapLogo } from "ui-components/src/images/netapp-services/ic-banner-cvo.svg";
import { ReactComponent as CloudVolumesServiceLogo } from "ui-components/src/images/netapp-services/ic-banner-cvs.svg";
import { ReactComponent as CloudSyncLogo } from "ui-components/src/images/netapp-services/ic-banner-cloud-sync.svg";
import { ReactComponent as CloudBackupLogo } from "ui-components/src/images/netapp-services/ic-banner-cloud-backup.svg";
import { ReactComponent as CloudInsightsLogo } from "ui-components/src/images/netapp-services/ic-banner-cloud-insights.svg";
import { ReactComponent as CloudTieringLogo } from "ui-components/src/images/netapp-services/ic-banner-cloud-tiering.svg";
import { ReactComponent as KubernetesServiceLogo } from "ui-components/src/images/netapp-services/ic-banner-kubernetes.svg";
import { ReactComponent as SaaSBackupLogo } from "ui-components/src/images/netapp-services/ic-banner-saas-backup.svg";
import { ReactComponent as CloudSecureLogo } from "ui-components/src/images/netapp-services/ic-banner-cloud-secure.svg";

import { ReactComponent as CalculatorIcon } from "ui-components/src/images/2-colors-icons/ic-calculator.svg";
import { ReactComponent as PricingIcon } from "ui-components/src/images/2-colors-icons/ic-pricing.svg";
import { ReactComponent as ApiIcon } from "ui-components/src/images/2-colors-icons/ic-api.svg";
import { ReactComponent as DemoIcon } from "ui-components/src/images/2-colors-icons/ic-monthly-demo.svg";
import { ReactComponent as AutomationIcon } from "ui-components/src/images/2-colors-icons/ic-automation.svg";

import { ReactComponent as AzureLogo } from 'ui-components/src/images/third-party-services/logo-azure.svg';
import { ReactComponent as GoogleCloudLogo } from 'ui-components/src/images/third-party-services/logo-google-cloud.svg';
import { ReactComponent as AWSLogo } from 'ui-components/src/images/third-party-services/logo-aws.svg';
import { registerFeature } from "../../middlewares/apiMiddleware";

import dashboardsMiddleware from "../../middlewares/featureApis/dashboardsMiddleware";
import Loadable from 'react-loadable';
import {Redirect, Route, Switch, NavLink} from "react-router-dom";
import {RightChevron} from "../cloud-assessment/summary-components/Icons";
import ExternalLink from "../widgets/ExternalLink";

registerFeature("DASHBOARDS", dashboardsMiddleware);

const CloudSyncActivatedDashboard = Loadable({
    loader: ()  => import('./CloudSyncActivatedDashboard' /* webpackChunkName: "CloudSyncActivatedDashboard" */),
    loading: () => <div/>
});


const CloudSyncDashboardDumb = ({ cloudSync, activeFeatures }) => {
    return (cloudSync.status === STATUS_SUCCESS || cloudSync.status === STATUS_ERROR) && <DashboardContainer
        category="services"
        serviceKey="cloudSync"
        title="Cloud Sync"
        Icon={CloudSyncLogo}
        iconStyle={{width: 94, height: 94}}
        productText="Cloud Sync is NetApp’s service for rapid and secure data synchronization. Whether you need to transfer files between on-premises NFS or CIFS file shares, Amazon S3 object format, Azure Blob, IBM Cloud Object Storage or NetApp StorageGRID® Webscale appliance, Cloud Sync moves the files where you need them quickly and securely."
        gettingStartedLink="dashboards.cloudSync.gettingStarted"
        contactUsEmail="saas.support@netapp.com"
        gettingStartedContent={[
            {
                Icon: DemoIcon,
                title: "FAQ",
                text: "Frequently asked questions",
                linkKey: "dashboards.cloudSync.faq"
            },
            {
                Icon: PricingIcon,
                title: "Supported Sync Relationships",
                text: "Learn about the supported source and target protocols for data transfer",
                linkKey: "dashboards.cloudSync.supportedSyncRelationships"
            },
            {
                Icon: ApiIcon,
                title: "API",
                text: "Cloud Sync Rest API",
                linkKey: "dashboards.cloudSync.api"
            }
        ]}
        footerContent={{
            title: "Cloud Sync Documentation & Support",
            links: [
                {
                    text: "Getting Started Guide",
                    linkKey: "dashboards.cloudSync.gettingStarted"
                },
                {
                    text: "Documentation",
                    linkKey: "dashboards.cloudSync.documentation"
                },
                {
                    text: "FAQ",
                    linkKey: "dashboards.cloudSync.faq"
                },
                {
                    text: "Blog",
                    linkKey: "dashboards.cloudSync.blog"
                }
            ]
        }}
        ActivatedDashboard={activeFeatures.activatedDashboards && cloudSync.status === STATUS_SUCCESS && CloudSyncActivatedDashboard}
    />
};

const mapStateToPropsCloudSync = state => {
    return {
        cloudSync: state.services.cloudSync,
        activeFeatures: state.features.active
    };
};

export const CloudSyncDashboard = connect(mapStateToPropsCloudSync)(CloudSyncDashboardDumb);

export const CloudVolumesOntapDashboard = () => <DashboardContainer
    category="storage"
    title="Cloud Volumes ONTAP"
    serviceKey="cloudVolumesOntap"
    Icon={CloudVolumesOntapLogo}
    iconStyle={{width: 148, height: 94}}
    productText="Cloud Volumes ONTAP is a powerful, cost-effective, and easy-to-use data management solution for your cloud workloads. The familiar and reliable Cloud Volumes ONTAP data management software with its data protection and storage efficiency features, now available in the AWS or Azure cloud."
    gettingStartedLink="dashboards.cloudVolumesOntap.gettingStarted"
    contactUsEmail="saas.support@netapp.com"
    gettingStartedContent={[
        {   Icon: CalculatorIcon,
            title: "TCO Calculator",
            text: "Calculate your Cloud Volumes ONTAP TCO on AWS and Azure",
            linkKey: "dashboards.cloudVolumesOntap.tcoCalculators"
        },
        {   Icon: PricingIcon,
            title: "Pricing",
            text: "Cloud Volumes ONTAP pricing for AWS and Azure",
            linkKey: "dashboards.cloudVolumesOntap.pricing"
        },
        {   Icon: ApiIcon,
            title: "API",
            text: "Cloud Volumes ONTAP Rest API",
            linkKey: "dashboards.cloudVolumesOntap.api"
        },
        {   Icon: AutomationIcon,
            title: "Automation Samples",
            text: "Cloud Manager and Cloud Volumes ONTAP automation samples",
            linkKey: "dashboards.cloudVolumesOntap.automationSamples"
        }
    ]}
    footerContent={{
        title: "Cloud Volumes ONTAP Documentation & Support",
        links: [
            {
                text: "Getting Started Guide",
                linkKey: "dashboards.cloudVolumesOntap.gettingStarted"
            },
            {
                text: "Documentation",
                linkKey: "dashboards.cloudVolumesOntap.documentation"
            },
            {
                text: "API",
                linkKey: "dashboards.cloudVolumesOntap.api"
            },
            {
                text: "Blog",
                linkKey: "dashboards.cloudVolumesOntap.blog"
            }
        ]
    }}
/>;

const CVSAzure = () => <React.Fragment>
    <p>A Microsoft Azure native service built on NetApp technology, giving you the file capabilities in Azure even your core business applications require.<ExternalLink linkKey="launchPad.marketing.cloudVolumesServiceAzure" trackCategory="dashboards" className={styles['cvs-read-more']} newTab>Learn More<RightChevron/></ExternalLink></p>
    <ExternalLink linkKey="launchPad.services.cloudVolumesServiceAzurePreview" trackCategory="dashboards" className={styles['cta-no-center']} newTab>Register for Preview</ExternalLink>
</React.Fragment>;

const CVSGCP = () => <React.Fragment>
    <p>A Google Cloud integrated file service with the performance, availability, and security requried to efficiently run your business-critical applications.<ExternalLink linkKey="launchPad.marketing.cloudVolumesServiceGcp" trackCategory="dashboards" className={styles['cvs-read-more']} newTab>Learn More<RightChevron/></ExternalLink></p>
    <ExternalLink linkKey="launchPad.services.cloudVolumesServiceGooglePreview" trackCategory="dashboards" className={styles['cta-no-center']} newTab>Register for Preview</ExternalLink>
</React.Fragment>;

const CVSAWS = () => <React.Fragment>
    <p>A fully managed, cloud service that enables you to move your mission-critical workloads and applications to the cloud, and manage them with ease. <ExternalLink linkKey="launchPad.marketing.cloudVolumesServiceAws" trackCategory="dashboards" className={styles['cvs-read-more']} newTab>Learn More<RightChevron/></ExternalLink></p>
    <ExternalLink linkKey="launchPad.services.cloudVolumesServiceAws" trackCategory="dashboards" className={styles['cta-no-center']} newTab>Go to CVS AWS</ExternalLink>
</React.Fragment>;

const CloudVolumesServiceCustom = () => <section className={styles["cloud-volumes-service-custom"]}>
    <h3>Delivers High Performance File Services to Your Business Critical Applications</h3>
    <div className={styles["cloud-volumes-service-switcher-container"]}>
        <NavLink to="/dashboard/cloud-volumes-service/azure" className={styles['cloud-volumes-service-switcher']} activeClassName={styles['cvs-active']}><AzureLogo/></NavLink>
        <NavLink to="/dashboard/cloud-volumes-service/gcp" className={styles['cloud-volumes-service-switcher']} activeClassName={styles['cvs-active']}><GoogleCloudLogo/></NavLink>
        <NavLink to="/dashboard/cloud-volumes-service/aws" className={styles['cloud-volumes-service-switcher']} activeClassName={styles['cvs-active']}><AWSLogo/></NavLink>
    </div>
    <div className={styles["cloud-volumes-service-container"]}>
        <Switch>
            <Route path="/dashboard/cloud-volumes-service/azure" render={() => <CVSAzure/>}/>
            <Route path="/dashboard/cloud-volumes-service/gcp" render={() => <CVSGCP/>}/>
            <Route path="/dashboard/cloud-volumes-service/aws" render={() => <CVSAWS/>}/>
            <Redirect to="/dashboard/cloud-volumes-service"/>
        </Switch>
    </div>
</section>;

export const CloudVolumesServiceDashboard = () => <DashboardContainer
    category="storage"
    title="Cloud Volumes Service"
    serviceKey="cloudVolumesService"
    Icon={CloudVolumesServiceLogo}
    CustomPane={CloudVolumesServiceCustom}
    iconStyle={{width: 120, height: 125}}
/>;

export const NetAppKubernetesServiceDashboard = () => <DashboardContainer
    category="controls"
    title="NetApp Kubernetes Service"
    serviceKey="kubernetesService"
    Icon={KubernetesServiceLogo}
    iconStyle={{width: 126, height: 68}}
    productText="The Universal Control Plane for Managed Kubernetes now available for everyone. Scale from 1 developer to thousands. The simplest way to deploy a Kubernetes cluster to the clouds. Deploy a production-ready Kubernetes cluster in 3 clicks when you want and where you want it."
    gettingStartedLink="dashboards.kubernetesService.gettingStarted"
/>;

export const CloudInsightsDashboard = () => <DashboardContainer
    category="analytics"
    title="Cloud Insights"
    serviceKey="cloudInsights"
    Icon={CloudInsightsLogo}
    iconStyle={{width: 118, height: 80}}
    productText="NetApp Cloud Insights is an infrastructure monitoring tool that gives you visibility into your complete infrastructure. With Cloud Insights, you can monitor, troubleshoot and optimize all your resources including your public clouds and your private data centers."
    gettingStartedLink="dashboards.cloudInsights.gettingStarted"
/>;

export const SaaSBackupDashboard = () => <DashboardContainer
    category="services"
    title="SaaS Backup"
    serviceKey="saasBackup"
    Icon={SaaSBackupLogo}
    iconStyle={{width: 103, height: 103}}
    productText="Guard your Office 365 and Salesforce data with secure backup and restore, protecting your data from threats and accidental deletion."
    gettingStartedLink="dashboards.saasBackup.gettingStarted"
/>;

export const CloudSecureDashboard = () => <DashboardContainer
    category="services"
    title="Cloud Secure"
    serviceKey="cloudSecure"
    Icon={CloudSecureLogo}
    iconStyle={{width: 80, height: 96}}
    productText="Securely innovate by gaining actionable intelligence on insider threats."
/>;

export const CloudTieringDashboard = () => <DashboardContainer
    category="services"
    title="Cloud Tiering"
    serviceKey="cloudTiering"
    Icon={CloudTieringLogo}
    iconStyle={{width: 101, height: 86}}
    productText="Lift and don't shift. Free up high-performance AFF storage space by automatically tiering infrequently-used data to the cloud. NetApp’s Cloud Tiering service allows you to retain your on-prem, high-performance AFF (and FAS SSD) storage and combine it with the benefits of cloud economics, leveraging the low costs of Azure Blob, Amazon S3, and IBM Cloud Object Storage."
/>;

export const CloudBackupServiceDashboard = () => <DashboardContainer
    category="services"
    title="Cloud Backup Service"
    serviceKey="cloudBackup"
    Icon={CloudBackupLogo}
    iconStyle={{width: 103, height: 93}}
    productText="Cloud Backup Service is an integrated feature for Cloud Volumes Service. It delivers fully managed backup and restore capabilities for protection, and long-term archive of your cloud data."
/>;