import React from 'react';
import styles from "./HowToGetStarted.module.scss"
import CloudCentralSecondaryHeader from "./../headers/CloudCentralSecondaryHeader"
import { ReactComponent as CloudAssessmentIcon } from "ui-components/src/images/2-colors-icons/ic-assessments.svg";
import { ReactComponent as CalculatorIcon } from "ui-components/src/images/2-colors-icons/ic-calculator.svg";
import { ReactComponent as AdvisorIcon } from "ui-components/src/images/2-colors-icons/ic-advisor.svg";

import { ReactComponent as BulletChevron } from "ui-components/src/images/monochrome-icons/bullet-chevron-icon.svg";

import { ReactComponent as CloudSyncLogo } from 'ui-components/src/images/netapp-services/ic-cloud-sync.svg';
import { ReactComponent as SaaSBackupLogo } from 'ui-components/src/images/netapp-services/ic-saas-backup.svg';
import { ReactComponent as CloudSentryLogo } from 'ui-components/src/images/netapp-services/ic-cloud-sentry.svg';
import { ReactComponent as CloudTieringLogo } from 'ui-components/src/images/netapp-services/ic-cloud-tiering.svg';
import { ReactComponent as CloudBackupLogo } from 'ui-components/src/images/netapp-services/ic-cloud-backup.svg';

const PrimaryBox = ({verb, text, buttonText}) => <div className={styles["primary-box"]}>
    <div>{verb}</div>
    <p>{text}</p>
    <h4>Start With</h4>
    <button>{buttonText}</button>
</div>;

const SecondaryBox = ({title, text, Icon}) => <div className={styles["secondary-box"]}>
    <Icon/>
    <h4>{title}</h4>
    <p>{text}</p>
    <a href="/">Read More <BulletChevron/></a>
</div>;

const TertiaryBox = ({Icon, title, text}) => <button className={styles["tertiary-box"]}>
    <Icon/>
    <h4>{title}</h4>
    <p>{text}</p>
</button>;

export default () =>
    <div className={styles.base}>
        <CloudCentralSecondaryHeader title="Welcome to Cloud Central"/>
        <section className={styles.primary}>
            <h3>Get Started With</h3>
            <div className="grid-row">
                <PrimaryBox verb="Extend" text="I want to extend my on-premise to the cloud" buttonText="Cloud Volumes ONTAP"/>
                <PrimaryBox verb="Deploy" text="I want to enhance my primary cloud workloads" buttonText="Cloud Volumes Service"/>
                <PrimaryBox verb="Build & Refactor" text="I want to build or refactor existing cloud applications" buttonText="NetApp Kubernetes Service"/>
                <PrimaryBox verb="Optimize" text="I want to analyze my hybrid cloud workloads" buttonText="Cloud Insights"/>
            </div>
        </section>
        <section className={styles.secondary}>
            <h3>Accelerate Your Work Process With</h3>
            <div className="grid-row-spread">
                <SecondaryBox title="Cloud Sync Service" text="Lorem ipsum dolor sit amet" Icon={CloudSyncLogo}/>
                <SecondaryBox title="SaaS Backup" text="Lorem ipsum dolor sit amet" Icon={SaaSBackupLogo}/>
                <SecondaryBox title="Cloud Secure" text="Lorem ipsum dolor sit amet" Icon={CloudSentryLogo}/>
            </div>
            <div className="grid-row-spread">
                <SecondaryBox title="Cloud Tiering" text="Lorem ipsum dolor sit amet" Icon={CloudTieringLogo}/>
                <SecondaryBox title="Cloud Backup Service" text="Lorem ipsum dolor sit amet" Icon={CloudBackupLogo}/>
            </div>
        </section>
        <section className={styles.tertiary}>
            <h3>Work Better With Our Tools</h3>
            <div className="grid-row">
                <TertiaryBox Icon={AdvisorIcon} title="Cloud Advisor" text="Analyze your on-prem environment using Active IQ data to build your cloud strategy"/>
                <TertiaryBox Icon={CloudAssessmentIcon} title="Cloud Assessment" text="Monitor your cloud storage resources, optimize cloud efficiency and data protection"/>
                <TertiaryBox Icon={CalculatorIcon} title="TCO Calculator" text="Easily calculate your Cloud Volumes ONTAP Total Cost of Ownership on AWS and Azure"/>
            </div>
        </section>
    </div>
;