import React from 'react';
import {Link} from 'react-router-dom';
import {connect} from 'react-redux';
import { ReactComponent as AzureLogo } from 'ui-components/src/images/third-party-services/logo-azure.svg';
import { ReactComponent as GoogleCloudLogo } from 'ui-components/src/images/third-party-services/logo-google-cloud.svg';
import { ReactComponent as AWSLogo } from 'ui-components/src/images/third-party-services/logo-aws.svg';
import {ReactComponent as FaqIcon} from 'ui-components/src/images/2-colors-icons/faq.svg';
import {ReactComponent as CloudVolumesLogo} from 'ui-components/src/images/netapp-services/ic-cvs.svg';
import {ReactComponent as ONTAPCloudLogo} from 'ui-components/src/images/netapp-services/ic-cvo.svg';
import {ReactComponent as CloudSyncLogo} from 'ui-components/src/images/netapp-services/ic-cloud-sync.svg';
import {ReactComponent as SaaSBackupLogo} from 'ui-components/src/images/netapp-services/ic-saas-backup.svg';
import {ReactComponent as CloudInsightsLogo} from 'ui-components/src/images/netapp-services/ic-cloud-insights.svg';
import {ReactComponent as KubernetesLogo} from 'ui-components/src/images/netapp-services/ic-kubernetes.svg';
import {ReactComponent as CloudBackupServiceLogo} from 'ui-components/src/images/netapp-services/ic-cloud-backup.svg';
import {ReactComponent as CloudTieringServiceLogo} from 'ui-components/src/images/netapp-services/ic-cloud-tiering.svg';
import {ReactComponent as ContactUsIcon} from 'ui-components/src/images/2-colors-icons/contact-us.svg';
import {ReactComponent as DemoIcon} from 'ui-components/src/images/2-colors-icons/demo.svg';
import {ReactComponent as TrainingIcon} from 'ui-components/src/images/2-colors-icons/ic-training.svg';
import {ReactComponent as PressReleaseIcon} from 'ui-components/src/images/2-colors-icons/ic-press-release.svg';
import {ReactComponent as RocketIcon} from 'ui-components/src/images/2-colors-icons/rocket.svg';
import CloudVolumesONTAPContent from './sales-content/cloudVolumesONTAPContent';
import CloudVolumesServiceContent from './sales-content/cloudVolumesServiceContent';
import CloudSyncContent from './sales-content/cloudSyncContent';
import SaaSBackupContent from './sales-content/saasBackupContent';
import CloudInsightsContent from './sales-content/cloudInsightsContent';
import KubernetesServiceContent from './sales-content/kubernetesServiceContent';
import CloudBackupServiceContent from './sales-content/cloudBackupServiceContent';
import CloudTieringContent from './sales-content/cloudTieringContent';
import TextTruncate from 'react-text-truncate';
import {openDialog} from './../dialog/Dialog';
import {ConnectedOccmDemoDialog} from "./SalesToolsDialogs";
import {ContactUsDialog} from "./../dialog/ContactUsDialogs"
import ExternalLink from "./../widgets/ExternalLink";
import classNames from "classnames";
import cssGrid from "ui-components/src/grid/grid.module.scss";
import card from "ui-components/src/card/card.module.scss";
import layout from "ui-components/src/layout/layout.module.scss";
import styles from "./SalesToolsServiceView.module.scss";

const CloudVolumesServiceTopButtons = () =>
    <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-3-lg"])}>
        <Link style={{justifyContent: "center"}} className={card.card} to="/netapp-internal/cloud-volumes-service/azure">
            <AzureLogo style={{width: "210px", height: "40px", margin: "0"}}/>
        </Link>
        <Link style={{justifyContent: "center"}} className={card.card} to="/netapp-internal/cloud-volumes-service/aws">
            <AWSLogo style={{width: "210px", height: "37px", margin: "0"}}/>
        </Link>
        <Link style={{justifyContent: "center"}} className={card.card} to="/netapp-internal/cloud-volumes-service/google">
            <GoogleCloudLogo style={{width: "210px", height: "37px", margin: "0"}}/>
        </Link>
    </div>
;

const CloudVolumesONTAPTopButtons = ({occmDemoReset}) =>
    <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-3-lg"])}>
        <ExternalLink className={card.card} linkKey="internal.sales.cloudVolumesONTAP.cloudVolumesONTAPFAQLink" newTab>
            <FaqIcon/>
            <div>FAQ</div>
        </ExternalLink>
        <button className={card.card} onClick={(el) => {
            occmDemoReset();
            return openDialog(<ConnectedOccmDemoDialog className='occm-demo-dialog'/>, el.target);
        }}>
            <DemoIcon/>
            <div>Demo Environment</div>
        </button>
        <Link className={card.card} to="/netapp-internal/cloud-volumes-ontap/training">
            <TrainingIcon/>
            <div>Training</div>
        </Link>
        <button className={card.card}
                onClick={(el) => openDialog(<ContactUsDialog className="contact-us-dialog"/>, el.target)}>
            <ContactUsIcon/>
            <div>Contact Us</div>
        </button>
    </div>
;

const mapDispatchToProps = dispatch => {
    return {
        occmDemoReset: () => {
            dispatch({
                type: "OCCM-DEMO-RESET",
            })
        }
    }
};

const mapStateToProps = state => {
    return {
        occmDemo: state.internal.occmDemo,
    };
};

const ConnectedCloudVolumesONTAPTopButtons = connect(mapStateToProps, mapDispatchToProps)(CloudVolumesONTAPTopButtons);

const CloudSyncTopButtons = () =>
    <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-3-lg"])}>
        <ExternalLink className={card.card} linkKey="internal.sales.cloudSync.cloudSyncFAQLink" newTab>
            <FaqIcon/>
            <div>FAQ</div>
        </ExternalLink>
        <ExternalLink className={card.card} linkKey="internal.sales.cloudSync.cloudSyncBusinessValueAndUseCasesLink"
                      newTab>
            <TrainingIcon/>
            <div>Training</div>
        </ExternalLink>
        <button className={card.card}
                onClick={(el) => openDialog(<ContactUsDialog className="contact-us-dialog"/>, el.target)}>
            <ContactUsIcon/>
            <div>Contact Us</div>
        </button>
    </div>
;

const SaaSBackupTopButtons = () =>
    <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-2-lg"])}>
        <ExternalLink className={card.card} linkKey="internal.sales.saasBackup.saasBackupFAQLink" newTab>
            <FaqIcon/>
            <div>FAQ</div>
        </ExternalLink>
        <button className={card.card} onClick={(el) => openDialog(<ContactUsDialog email='ng-SaaSBackup@netapp.com'
                                                                                   className="contact-us-dialog"/>, el.target)}>
            <ContactUsIcon/>
            <div>Contact Us</div>
        </button>
    </div>
;

const CloudInsightsTopButtons = () =>
    <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-2-lg"])}>
        <ExternalLink className={card.card} linkKey="internal.sales.cloudInsights.cloudInsightsFAQLink" newTab>
            <FaqIcon/>
            <div>FAQ</div>
        </ExternalLink>
        <button className={card.card}
                onClick={(el) => openDialog(<ContactUsDialog email='ng-team-Holden-James-AllEmp@netapp.com'
                                                             className="contact-us-dialog"/>, el.target)}>
            <ContactUsIcon/>
            <div>Contact Us</div>
        </button>
    </div>
;

const KubernetesServiceTopButtons = () =>
    <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-3-lg"])}>
        <ExternalLink className={card.card} linkKey="internal.sales.kubernetesService.launchDeckLink" newTab>
            <RocketIcon/>
            <div>Launch Deck</div>
        </ExternalLink>
        <ExternalLink className={card.card} linkKey="internal.sales.kubernetesService.pressReleaseLink" newTab>
            <PressReleaseIcon/>
            <div>Press release</div>
        </ExternalLink>
        <button className={card.card} onClick={(el) => openDialog(<ContactUsDialog email='ng-NKS@netapp.com'
                                                                                   className="contact-us-dialog"/>, el.target)}>
            <ContactUsIcon/>
            <div>Contact Us</div>
        </button>
    </div>
;

const CloudBackupServiceTopButtons = () =>
    <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-2-lg"])}>
        <button className={card.card} onClick={(el) => openDialog(<ContactUsDialog email='Chris.Wong@netapp.com'
                                                                                   className="contact-us-dialog"/>, el.target)}>
            <ContactUsIcon/>
            <div>Contact Us</div>
        </button>
        <ExternalLink className={card.card} linkKey="internal.sales.cloudBackupService.cloudBackupFAQLink" newTab>
            <FaqIcon/>
            <div>FAQ</div>
        </ExternalLink>
    </div>
;

const CloudTieringTopButtons = () =>
    <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-md"], cssGrid["col-2-lg"])}>
        <ExternalLink className={card.card} linkKey="internal.sales.cloudTiering.cloudTieringFAQLink" newTab>
            <FaqIcon/>
            <div>FAQ</div>
        </ExternalLink>
        <Link className={card.card} to="/demo">
            <DemoIcon/>
            <div>Demo Environment</div>
        </Link>
    </div>
;

const InternalSales = ({serviceIcon, serviceInfo, topButtons, category}) => {
    const ServiceIcon = serviceIcon;
    const TopButtons = topButtons;

    const categoryToClass = {
        "category-storage":"storage-info-card",
        "category-services":"services-info-card",
        "category-controls":"controls-info-card",
        "category-analytics":"analytics-info-card"
    };

    const InfoCard = ({item}) => {
        if(item.linkKey) {
            return (
                <ExternalLink linkKey={item.linkKey} className={styles[categoryToClass[category]]} newTab>
                    <span className={styles.title}>{item.title}</span>
                    {item.tags && <span className={styles.keywords}>{item.tags.join(' | ')}</span>}
                    {item.description && <div className={styles.details} title={item.description}><TextTruncate line={3} truncateText="…" text={item.description}/></div>}
                </ExternalLink>
            );
        } else {
            return (
                <Link to={item.link} className={styles[categoryToClass[category]]}>
                    <span className={styles.title}>{item.title}</span>
                    {item.tags && <span className={styles.keywords}>{item.tags.join(' | ')}</span>}
                    {item.description && <div className={styles.details} title={item.description}><TextTruncate line={1} truncateText="…" text={item.description}/></div>}
                </Link>
            );
        }
    };

    return <div className={classNames(layout["main-content-container"], "sales-tools-main", "service-view")}>
        <h4 className="service-title"><ServiceIcon className="service-icon"/>{serviceInfo.productName}</h4>
        <TopButtons/>
        {serviceInfo.salesItems.length > 0 && <h4>{serviceInfo.productName === "Cloud Volumes Service & Azure NetApp Files" ? "Common Sales Tools" : "Sales Tools"}</h4>}
        <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-lg"])}>
            {serviceInfo.salesItems.map(item => <InfoCard key={item.title} item={item}/>)}
        </div>
    </div>
};

const cloudVolumesOntapTrainingItems = [
    {
        title: "Cloud Volumes ONTAP Fundamentals",
        linkKey: "internal.sales.cloudVolumesONTAP.training.cloudVolumesOntapFundamentals",
        description: "This web-based course describes the features and benefits of the NetApp Cloud Volumes ONTAP system. The course helps enable you to explain the architecture and functionality of cloud-based ONTAP storage. Also, the course introduces basic administration, configuration, and management of the Cloud Volumes ONTAP system using OnCommand Cloud Manager. The Cloud Volumes ONTAP Fundamentals course was written for storage administrators of any experience level.",
        tags: ["Duration : 00:40"]
    },
    {
        title: "Cloud Volumes ONTAP Deployment and Management for Azure",
        linkKey: "internal.sales.cloudVolumesONTAP.training.cloudVolumesOntapDeploymentAndManagementForAzure",
        description: "In this course, you learn how to deploy and administer NetApp Cloud Volumes ONTAP for Azure. You use OnCommand Cloud Manager to deploy and manage Cloud Volumes ONTAP, which includes volume management. ",
        tags: ["Duration : 02:00"]
    },
    {
        title: "NetApp Cloud Volumes ONTAP: Understanding the Business Value and Use Cases",
        linkKey: "internal.sales.cloudVolumesONTAP.training.netAppCloudVolumesOntapUnderstandingTheBusinessValueAndUseCases",
        description: "In this course, you learn how to initiate a consultative conversation with customers about their challenges with digital transformation. The course focuses on the NetApp Cloud Volumes ONTAP solution, including features and functions, proven use cases, and customer success stories. You learn how to identify and qualify potential buyers, position NetApp Cloud Volumes ONTAP, and manage objections. You also learn about cloud workshop offerings to help you sell Cloud Volumes ONTAP.",
        tags: ["Duration : 00:30"]
    },
    {
        title: "Technical Overview of Cloud Volumes ONTAP",
        linkKey: "internal.sales.cloudVolumesONTAP.training.technicalOverviewOfCloudVolumesOntap",
        description: "This course covers the customer challenges addressed by NetApp Cloud Volumes ONTAP. It covers the features and benefits of Cloud Volumes ONTAP. This course also covers the components, architecture, and the primary use cases of Cloud Volumes ONTAP.",
        tags: ["Duration : 00:30"]
    }
];

export const CloudVolumesOntapTraining = () => {
    return <div className={classNames(layout["main-content-container"], "sales-tools-main", "service-view")}>
        <h4 className="service-title"><ONTAPCloudLogo className="service-icon"/>Cloud Volumes ONTAP Training</h4>

        <div className={classNames(cssGrid["col-1-sm"], cssGrid["col-2-lg"])}>
            {cloudVolumesOntapTrainingItems.map(item => {
                return (
                    <ExternalLink linkKey={item.linkKey} className={styles["storage-info-card"]} newTab>
                        <span className={styles.title}>{item.title}</span>
                        {item.tags && <span className={styles.keywords}>{item.tags.join(' | ')}</span>}
                        {item.description && <div className={styles.details} title={item.description}><TextTruncate line={3} truncateText="…" text={item.description}/></div>}
                    </ExternalLink>
                );
            })}
        </div>
    </div>
};

const CloudVolumesServiceSalesTools = () =>
    <InternalSales serviceInfo={CloudVolumesServiceContent}
                   serviceIcon={CloudVolumesLogo}
                   topButtons={CloudVolumesServiceTopButtons}
                   category="category-storage"/>;

const CloudVolumesONTAPSalesTools = () =>
    <InternalSales serviceInfo={CloudVolumesONTAPContent}
                   serviceIcon={ONTAPCloudLogo}
                   topButtons={ConnectedCloudVolumesONTAPTopButtons}
                   category="category-storage"/>;

const CloudSyncSalesTools = () =>
    <InternalSales serviceInfo={CloudSyncContent}
                   serviceIcon={CloudSyncLogo}
                   topButtons={CloudSyncTopButtons}
                   category="category-services"/>;

const SaaSBackupSalesTools = () =>
    <InternalSales serviceInfo={SaaSBackupContent}
                   serviceIcon={SaaSBackupLogo}
                   topButtons={SaaSBackupTopButtons}
                   category="category-services"/>;

const CloudInsightsSalesTools = () =>
    <InternalSales serviceInfo={CloudInsightsContent}
                   serviceIcon={CloudInsightsLogo}
                   topButtons={CloudInsightsTopButtons}
                   category="category-analytics"/>;

const KubernetesServiceSalesTools = () =>
    <InternalSales serviceInfo={KubernetesServiceContent}
                   serviceIcon={KubernetesLogo}
                   topButtons={KubernetesServiceTopButtons}
                   category="category-controls"/>;

const CloudBackupServiceSalesTools = () =>
    <InternalSales serviceInfo={CloudBackupServiceContent}
                   serviceIcon={CloudBackupServiceLogo}
                   topButtons={CloudBackupServiceTopButtons}
                   category="category-services"/>;

const CloudTieringSalesTools = () =>
    <InternalSales serviceInfo={CloudTieringContent}
                   serviceIcon={CloudTieringServiceLogo}
                   topButtons={CloudTieringTopButtons}
                   category="category-services"/>;

export {
    CloudVolumesServiceSalesTools,
    CloudVolumesONTAPSalesTools,
    CloudSyncSalesTools,
    SaaSBackupSalesTools,
    CloudInsightsSalesTools,
    KubernetesServiceSalesTools,
    CloudBackupServiceSalesTools,
    CloudTieringSalesTools
}