import React from 'react';
import _ from 'lodash';
import styles from "./AmericasGlobalSpiff.module.scss"
import {Link, Redirect, Route, Switch, NavLink} from "react-router-dom";
import SpiffAccounts from "./SpiffAcounts";
import SpiffOverview from "./SpiffOverview";
import SpiffWinners from "./SpiffWinners";
import {scrollToTop} from "./../../../utils/utils";

import {ReactComponent as BackArrowIcon} from "ui-components/src/images/monochrome-icons/back-arrow-icon.svg";
import {ReactComponent as ChatInfoIcon} from "ui-components/src/images/2-colors-icons/ic-chat-info.svg";
import {ReactComponent as LineItemIcon} from "ui-components/src/images/2-colors-icons/ic-line-item.svg";
import {ReactComponent as MedallionIcon} from "ui-components/src/images/2-colors-icons/ic-medallion.svg";
import store from "../../../store";
import classNames from 'classnames';

import { ReactComponent as TrophyIcon } from "ui-components/src/images/2-colors-icons/ic-trophy.svg";
import moment from "moment";

const CountDown = () => {
    const lastDay = moment("2019-04-28");
    const now = moment();
    const daysLeft = Math.max(lastDay.diff(now, 'days'), 0);

    return <div className={styles.countdown}>
        <TrophyIcon/> {daysLeft} DAYS TO THE FINISH LINE!
    </div>
};

const NavCard = ({to, disabled, children}) => <NavLink to={to} disabled={disabled} activeClassName="active" onClick={scrollToTop}>
    {children}
    <div className="the-thin-blue-line"/>
</NavLink>;

const SpiffHeader = () => {
    return <React.Fragment><header className={classNames(styles.header, 'nav-adjusted-fixed-pane')}>
        <div className="header-container">
            <Link to="/netapp-internal" className="back"><BackArrowIcon/>Back</Link>
            <h1>Americas & Globals Q4 CVO SPIFF</h1>
            <CountDown/>
            <div className={styles["links-container"]}>
                <NavCard to="/netapp-internal/americas-global-spiff/overview">
                    <ChatInfoIcon className="icon"/>
                    Rewards Program Overview
                </NavCard>
                <NavCard to="/netapp-internal/americas-global-spiff/accounts">
                    <LineItemIcon className="icon"/>
                    Target Accounts
                </NavCard>
                <NavCard to="/netapp-internal/americas-global-spiff/winners">
                    <MedallionIcon className="icon"/>
                    Winners & Front Runners
                </NavCard>
            </div>
        </div>
    </header>
    <div className={styles.filler}/>
    </React.Fragment>
};

const fetch = _.once(() => {
    store.dispatch({
        type: "INTERNAL:FETCH-AMERICAS-GLOBAL-SPIFF-DATA"
    })
});

export default () => <div>
    {fetch()}
    <SpiffHeader/>
    <Switch>
        <Route path="/netapp-internal/americas-global-spiff/overview" exact render={() => <SpiffOverview/>} />
        <Route path="/netapp-internal/americas-global-spiff/accounts" exact render={() => <SpiffAccounts/>}/>
        <Route path="/netapp-internal/americas-global-spiff/winners" exact render={() => <Redirect to="/netapp-internal/americas-global-spiff/winners/enterprise/team"/>}/>
        <Route path="/netapp-internal/americas-global-spiff/winners/partners" render={() => <SpiffWinners area="partners" type="team"/>}/>
        <Route path="/netapp-internal/americas-global-spiff/winners/:area/:type" render={({match: {params: {area, type}}}) => <SpiffWinners area={area} type={type}/>}/>
        <Redirect to="/netapp-internal/americas-global-spiff/overview"/>
    </Switch>
</div>;

