import React from 'react';
import styles from "./SpiffWinners.module.scss";
import { AgGridReact } from "ag-grid-react";
import classNames from "classnames";
import _ from "lodash";
import Popover from './../../widgets/Popover';
import connect from "react-redux/es/connect/connect";
import { Dialog } from "./../../dialog/Dialog";
import { scrollToTop } from "./../../../utils/utils";
import { ReactComponent as CloseXIcon } from "ui-components/src/images/monochrome-icons/x-icon.svg";
import { ReactComponent as Podium } from 'ui-components/src/images/monochrome-icons/ic-podium.svg';
import { ReactComponent as Licensing } from 'ui-components/src/images/monochrome-icons/ic-licensing.svg';
import { ReactComponent as Money } from 'ui-components/src/images/monochrome-icons/ic-money.svg';
import { ReactComponent as Customers } from 'ui-components/src/images/monochrome-icons/ic-customers.svg';
import { ReactComponent as InfoIcon } from "ui-components/src/images/monochrome-icons/ic-info-i.svg";
import { ReactComponent as BulletIcon } from "ui-components/src/images/monochrome-icons/bullet-chevron-icon.svg";
import { ReactComponent as Medal } from "ui-components/src/images/2-colors-icons/ic-winners.svg";
import { ReactComponent as Table } from "ui-components/src/images/monochrome-icons/ic-table-ph.svg";

import { NavLink } from 'react-router-dom';
import Loader from "../../../Loader";

const gradientEnd = {
    r: 32,
    g: 42,
    b: 248
};

const gradientStart = {
  r: 145,
  g: 229,
  b: 255
};

const interp = (value, first, last, gradientStart, gradientEnd) => {
    let coefficient = 0;
    if(value !== last ){
        coefficient = ((value - last) / (first - last));
    }
    return {
      r: gradientStart.r + (gradientEnd.r - gradientStart.r) * coefficient,
      g: gradientStart.g + (gradientEnd.g - gradientStart.g) * coefficient,
      b: gradientStart.b + (gradientEnd.b - gradientStart.b) * coefficient
    }
};

const asRgbString = (rgbObj) => `rgb(${rgbObj.r},${rgbObj.g},${rgbObj.b})`;

const percentWidth = (value, first, last) => {
    if(value === 0) {
        return 0;
    }
    return ((value - last) / (first - last)) * 60 + 10;
};

const Tab = ({title, to}) => <NavLink to={to} className={styles["tab"]} activeClassName={styles['active-tab']} onClick={scrollToTop}>{title}</NavLink>;
const Divider = () => <div className={styles["tab-divider"]}/>;

const AreaSelector = ({type}) => <header className={classNames(styles.header, "nav-adjusted-fixed-pane")}>
    <div className={styles.tabs}>
        <Tab title="Enterprise" to={`/netapp-internal/americas-global-spiff/winners/enterprise/${type}`}/>
        <Divider/>
        <Tab title="Commercial" to={`/netapp-internal/americas-global-spiff/winners/commercial/${type}`}/>
        <Divider/>
        <Tab title="USPS" to={`/netapp-internal/americas-global-spiff/winners/usps/${type}`}/>
        <Divider/>
        <Tab title="Canada/LATAM" to={`/netapp-internal/americas-global-spiff/winners/canada-latam/${type}`}/>
        <Divider/>
        <Tab title="Globals" to={`/netapp-internal/americas-global-spiff/winners/globals/${type}`}/>
        <Divider/>
        <Tab title="Partners" to={`/netapp-internal/americas-global-spiff/winners/partners`}/>
    </div>
</header>;

const DistrictDialogDumb = ({closeDialog, selectedDistrict: {name, minimumNumberOfLicenses, minimumNumberOfCustomers, place, fValue, numberOfCustomers, numberOfLicenses, passesThreshold}}) => <div>
    <header>
        {name}
        <button onClick={closeDialog}><CloseXIcon/></button>
    </header>
    <div className={styles["dialog-content"]}>
        <div className={styles["grid-layout"]}>
            <div className={styles["dialog-row"]}>
                <div>
                    <Podium style={{width: "31px", height: "29px"}}/>
                </div>
                <div>Your Place in the Competition</div>
                <div>{place}</div>
            </div>
            <div className={styles["dialog-row"]}>
                <div>
                    <Money style={{width: "35px", height: "35px"}}/>
                </div>
                <div>Total Amount Sold</div>
                <div>{fValue}</div>
            </div>
            <div className={styles["dialog-row"]}>
                <div>
                    <Customers style={{width: "36px", height: "37px"}}/>
                </div>
                <div>Number of Customers</div>
                <div>{numberOfCustomers}</div>
            </div>
            <div className={styles["dialog-row"]}>
                <div>
                    <Licensing style={{width: "30px", height: "38px"}}/>
                </div>
                <div>Number of licenses</div>
                <div>{numberOfLicenses}</div>
            </div>
            {!passesThreshold && <div className={classNames(styles["dialog-row"], styles["warning"])}>
                    <div>
                        <InfoIcon style={{width: "19px", height: "19px", fill: '#eb8e45'}}/>
                    </div>
                    <div style={{fontSize: "15px", lineHeight: "2", width: "449px", color: "#bd590b", fontWeight: "normal"}}>To be qualified for a win your team needs to sell a minimum of {minimumNumberOfLicenses} licenses to a minimum of {minimumNumberOfCustomers} customers.</div>
                </div>
            }
        </div>
    </div>
</div>;

const mapDialogStateToProps = state => {
    return {
        selectedDistrict: state.internal.americasGlobalSpiffSelectedDistrict
    }
};

const DistrictDialog = connect(mapDialogStateToProps)(DistrictDialogDumb);

const mapPartnersReportToProprs = state => {
    return {
        partners: state.internal.americasGlobalSpiffStatus === "SUCCESS" && state.internal.americasGlobalSpiffData.partners
    };
};

const PartnersReportDumb = ({ partners }) => <div className={styles["team-challenge"]}>
    {partners.map(({ name, value, fValue }) => <React.Fragment key={name}>
            <span className={styles['partner']}>
                {name}
                <BulletIcon className="bullet"/>
            </span>
            <div className={styles['district-value']}>
                <div style={{
                    backgroundColor: asRgbString(interp(value, _.head(partners).value, _.last(partners).value, gradientStart, gradientEnd)),
                    width: `calc(${percentWidth(value, _.head(partners).value, _.last(partners).value)}% )`,
                    height: 12,
                    display: "inline-block",
                    borderTopRightRadius: 8,
                    borderBottomRightRadius: 8,
                    minWidth: 2,
                    marginRight: 20
                }}/>
                <span>{fValue}</span>
            </div>
        </React.Fragment>
    )}
</div>;


const PartnersReport = connect(mapPartnersReportToProprs)(PartnersReportDumb);

const TeamChallengeDumb = ({area, openDialog, closeDialog, districtDialogOpen, districts}) => <div className={styles["team-challenge"]}>
    <Dialog
        open={districtDialogOpen}
        closeTrigger={closeDialog}
    >
        <DistrictDialog className={styles.dialog}/>
    </Dialog>

    { districts.map(({name, fValue, passesThreshold, value, minimumNumberOfCustomers, minimumNumberOfLicenses}) => <React.Fragment key={name}>
            <button className={passesThreshold ? styles['district'] : styles['district-no-pass']} onClick={() => openDialog(name, area)}>
                {!passesThreshold &&
                <Popover className={styles["info-popover"]} trigger="mouseover"  containerClassName="info-button"  component={<InfoIcon className="info"/>}>
                    <div>
                        To be qualified for a win your team needs to sell a minimum of {minimumNumberOfLicenses} licenses to a minimum of {minimumNumberOfCustomers} customers.
                    </div>
                </Popover>
                }
                {name}
                <BulletIcon className="bullet"/>
            </button>
            <div className={styles['district-value']}>
                <div style={{backgroundColor: asRgbString(interp(value, _.head(districts).value, _.last(districts).value, gradientStart, gradientEnd)),
                    width: `calc(${percentWidth(value, _.head(districts).value, _.last(districts).value)}% )`,
                    height: 12,
                    display: "inline-block",
                    borderTopRightRadius: 8,
                    borderBottomRightRadius: 8,
                    minWidth: 2,
                    marginRight: 20}}/>
                <span>{fValue}</span>
            </div>
        </React.Fragment>)
    }
</div>;

const TypeSwitcher = ({area}) => <header className={classNames(styles['type-switching'], "nav-adjusted-fixed-pane")}>
    <div className={styles['type-tabs']}>
        <NavLink to={`/netapp-internal/americas-global-spiff/winners/${area}/team`} className={styles['type-selector-left']} activeClassName={styles['type-selector-active']}  onClick={scrollToTop}>
            Team Challenge
        </NavLink>
        <NavLink to={`/netapp-internal/americas-global-spiff/winners/${area}/individual`} className={styles['type-selector-right']} activeClassName={styles['type-selector-active']}  onClick={scrollToTop}>
            Individual Challenge
        </NavLink>
    </div>
</header>;

const mapStateToProps = (state, ownProps) => {
    const {area} = ownProps;
    const districts = state.internal.americasGlobalSpiffStatus === "SUCCESS" && state.internal.americasGlobalSpiffData.teamChallenge[area];

    return {
        districtDialogOpen: !!state.internal.americasGlobalSpiffDistrictDialog,
        districts
    };
};

const mapDispatchToProps = dispatch => {
    return {
        openDialog: (districtName, area) => {
            dispatch({
                type: "INTERNAL:OPEN-DIALOG-AMERICAS-GLOBALS",
                payload: {
                    districtName,
                    area
                }
            })
        },
        closeDialog: () => {
            dispatch({
                type: "INTERNAL:CLOSE-DIALOG-AMERICAS-GLOBALS"
            })
        }
    }
};

const TeamChallenge = connect(mapStateToProps, mapDispatchToProps)(TeamChallengeDumb);

const Winner = props => {
    return (
        <div key={props.id} className={props.name ? styles["winner-item"] : styles["winner-item-empty"]}>
            <Medal/>
            <span>{props.name}</span>
        </div>
    );
};

const getColumnDefs = (isGlobals) => {
    const headers = isGlobals ? ["Name", "Role", "Area", "Licenses"] : ["Name", "Role", "Licenses"];

    const fields = {"Name":"name", "Role":"role", "Licenses":"licenses", "Area": "Area"};
    const cols = _.map(headers, (header => ({
        headerName: header,
        field: fields[header],
        sortable: true,
        suppressMenu: true,
        unSortIcon: true,
        autoHeight: true
    })));

    const licensesComparator = (valueA, valueB) => {
        const numA = Number(valueA);
        const numB = Number(valueB);
        if (!numA || !numB) {
            return 0;
        }
        return numA - numB;
    };
    // Add comparator to licenses colum so it will sort numerically instead of lexically
    isGlobals ? (cols[3].compator = licensesComparator) : (cols[2].compator = licensesComparator);
    return cols;
};

const mapChallengeStateToProps = (state, ownProps) => {
    const {area} = ownProps;
    const rules = state.internal.americasGlobalSpiffStatus === "SUCCESS" && state.internal.americasGlobalSpiffData.rules[area];
    const runners = state.internal.americasGlobalSpiffStatus === "SUCCESS" && state.internal.americasGlobalSpiffData.runners[area];
    return {
        rules,
        runners
    };
};

const Collections = ({runners, rules}) => {
    const winners = runners ? _.groupBy(runners.filter(winner => (winner.index || winner.index === 0)), "category") : []; // only runners with index are winners

    return rules.map((rule, i) => {
        let categoryWinners = _.sortBy(winners[rule.category], ["index"]); // sort winners category by rank
        const numberOfWinnersInCategory = categoryWinners ? categoryWinners.length : 0;
        const numberOfVouchersInCategory = rule.vouchers;
        // Consider case where there are more winners than vouchers
        const emptySpotsLeftInCategory = numberOfVouchersInCategory - numberOfWinnersInCategory;
        return (
            <div key={`${rule.category}-${i}`} className={styles["winners-grid"]}>
                <div className={styles["winners-category-span-2"]}>{rule.category}</div>
                {categoryWinners.splice(0, numberOfVouchersInCategory).map((winner,j) => <Winner key={`${i}-${j}-winner`} name={winner.name}/>)}
                {_.map(_.range(emptySpotsLeftInCategory > 0 ? emptySpotsLeftInCategory : 0), j => <Winner
                    key={`${i}-${j}-empty`}/>)}
            </div>
        );
    });
};

class IndividualChallenge extends React.Component {

    constructor(props) {
        super(props);
        this.state = {columnDefs: getColumnDefs(props.area === "globals")};
    }

    onFirstDataRendered(params) {
        this.api = params.api;
        params.api.sizeColumnsToFit();
    }

    onComponentStateChanged() {
        this.api.refreshCells({force: true});
    }

    componentDidUpdate(prevProps) {
        if(prevProps.area !== this.props.area){
            this.setState({columnDefs: getColumnDefs(this.props.area === "globals")}, () => {
                this.api.sizeColumnsToFit();
            });
        }
    }

    render() {
        return (
            <div className={styles["individual-challenge"]}>
                <Collections runners={this.props.runners} rules={this.props.rules}/>
                {this.props.runners ?
                <React.Fragment>
                    <div className={`${styles["table-title"]} ${styles["winners-category"]}`}>Front Runners</div>
                    <div className={`ag-theme-balham ${styles.table}`}>
                        <AgGridReact
                            enableColResize={false}
                            columnDefs={this.state.columnDefs}
                            onFirstDataRendered={this.onFirstDataRendered.bind(this)}
                            onComponentStateChanged={this.onComponentStateChanged.bind(this)}
                            suppressDragLeaveHidesColumns={true}
                            rowData={this.props.runners}
                            headerHeight="55"
                            suppressColumnVirtualisation="true">
                        </AgGridReact>
                    </div>
                </React.Fragment> :
                <div className={styles["no-runners-notification"]}>
                    <Table/>
                    <div>There are no front runners yet</div>
                </div>}
            </div>
        );
    }
}

const IndividualChallengeView = connect(mapChallengeStateToProps)(IndividualChallenge);

const SpiffWinners = ({area, type, errorMessage, status}) => <React.Fragment>
        {status === "PENDING" && <Loader/>}
        {status === "ERROR" && <div>
            {errorMessage}
        </div>}

        {status === "SUCCESS" && <React.Fragment>
            <AreaSelector type={type}/>
            {area !== "partners" && <TypeSwitcher area={area}/>}
            {(area !== "partners" && type === "team") && <TeamChallenge area={area}/>}
            {(area !== "partners" && type === "individual") && <IndividualChallengeView area={area}/>}
            {area === "partners" && <PartnersReport/>}
        </React.Fragment>}
    </React.Fragment>;

const mapSpiffWinnersStateToProps = (state) => {
    return {
        status: state.internal.americasGlobalSpiffStatus,
        errorMessage: state.internal.americasGlobalSpiffError
    }
};

export default connect(mapSpiffWinnersStateToProps)(SpiffWinners);