import React from 'react';
import "./LaunchPad.scss"
import { Link } from 'react-router-dom'
import { ReactComponent as CloudVolumesLogo }  from 'ui-components/src/images/netapp-services/ic-cvs.svg';
import { ReactComponent as ONTAPCloudLogo } from 'ui-components/src/images/netapp-services/ic-cvo.svg';
import { ReactComponent as CloudSyncLogo } from 'ui-components/src/images/netapp-services/ic-cloud-sync.svg';
import { ReactComponent as SaaSBackupLogo } from 'ui-components/src/images/netapp-services/ic-saas-backup.svg';
import { ReactComponent as OCILogo } from 'ui-components/src/images/netapp-services/ic-cloud-insights.svg';
import { ReactComponent as CloudSentryLogo } from 'ui-components/src/images/netapp-services/ic-cloud-sentry.svg';
import { ReactComponent as KubernetesServiceLogo } from 'ui-components/src/images/netapp-services/ic-kubernetes.svg';
import { ReactComponent as CloudTieringLogo } from 'ui-components/src/images/netapp-services/ic-cloud-tiering.svg';
import { ReactComponent as CloudBackupLogo } from 'ui-components/src/images/netapp-services/ic-cloud-backup.svg';
import BarLoader from "./../bar-loader/BarLoader.js";
import moment from 'moment';
import { WarningIcon } from 'components/svg-icons/Icons';
import { connect } from 'react-redux'
import * as actions from "./../../actions";

import {Dialog} from "./../dialog/Dialog"
import SelectCloudVolumesDialog from "./SelectCloudVolumesDialog"
import ExternalLink from './../widgets/ExternalLink'
import Popover from "./../../components/widgets/Popover"
import popoverStyle from "ui-components/src/Popover/popover.module.scss"

const isOlderThanThirtyMinutes = (date) => moment().subtract(30, 'minutes').valueOf() > date;

const MoreInfoLinkNew = ({serviceKey}) => (
    <div className="more-info">
        <ExternalLink linkKey={`launchPad.marketing.${serviceKey}`}>More Info</ExternalLink>
    </div>
);

const ServiceLinkNew = ({serviceKey, text, style}) =>
    <ExternalLink linkKey={`launchPad.services.${serviceKey}`} className="button service-link" style={style}>{text}</ExternalLink>;

const CloudSyncBox = ({ serviceData }) =>
    <div className="grid-box">
        <div className="box">
            <CloudSyncLogo/>
            <div className="title">Cloud Sync</div>
            { serviceData.status === actions.STATUS_PENDING && <div style={{position: "absolute", top: 165, width: "100%", height: "55px", lineHeight: "55px"}}>Loading...</div> }
            <ServiceLinkNew serviceKey={serviceData.serviceKey} text={serviceData.text}/>
            { serviceData.status === actions.STATUS_SUCCESS && <span>
                { serviceData.data.subscriptionStatus === 'subscribe-success' && <p>Status: Subscribed</p> }
                { serviceData.data.daysLeftForTrial === -1 && (serviceData.data.subscriptionStatus === 'unsubscribed-init' || serviceData.data.subscriptionStatus === 'unsubscribed-pending' || serviceData.data.subscriptionStatus === 'unsubscribed-success' || serviceData.data.subscriptionStatus === 'resolved-failed') && <p>Status: Unsubscribed</p> }
                { serviceData.data.subscriptionStatus !== 'subscribe-success' && serviceData.data.daysLeftForTrial && serviceData.data.daysLeftForTrial > -1 && <p>Days Left in Trial: <span style={{color: "#ff0000"}}> {serviceData.data.daysLeftForTrial} </span> </p>}
                </span> }
            <MoreInfoLinkNew serviceKey="cloudSync"/>
        </div>
    </div>
;

const SaasBackupBox = ({serviceData}) =>
    <div className="grid-box">
        <div className="box">
            <SaaSBackupLogo/>
            <div className="title">SaaS Backup</div>
            <ServiceLinkNew serviceKey={serviceData.serviceKey} text={serviceData.text}/>
            <MoreInfoLinkNew serviceKey="saasBackup"/>
        </div>
    </div>
;

const CloudInsightsBox = ({serviceData}) =>
    <div className="grid-box">
        <div className="box">
            <OCILogo/>
            <div className="title">Cloud Insights</div>
            { serviceData.status === actions.STATUS_PENDING && <div style={{position: "absolute", top: 165, width: "100%", height: "55px", lineHeight: "55px"}}>Loading...</div> }
            { serviceData.status !== actions.STATUS_PENDING && <ServiceLinkNew serviceKey={serviceData.serviceKey} text={serviceData.text}/>}
            <MoreInfoLinkNew serviceKey="cloudInsights"/>
        </div>
    </div>
;

const CloudVolumesONTAPBox = ({ occms }) =>
    <div className="grid-box">
        <div className="box">
            <ONTAPCloudLogo/>
            <div className="title">Cloud Volumes ONTAP</div>
            { occms.view === "loading" && <div style={{position: "absolute", top: 165, width: "100%", height: "55px", lineHeight: "55px"}}>Loading...</div> }
            { occms.view === "start-free-trial" && <ServiceLinkNew serviceKey="occmSetupService" text="Start Free Trial"/>}
            { occms.view === "create-new" && <ServiceLinkNew serviceKey="occmSetupService" text="Create Cloud Manager"/> }
            { occms.view === "has-one-ready" && <ExternalLink linkKey="launchPad.services.cloudManager" href={occms.data.occms[0].primaryCallbackUri} className="button service-link">Go to Cloud Manager</ExternalLink> }
            { occms.view === "has-one-initializing" && <div className="waiting-for-launch">Launching Instance</div>}
            { occms.view === "has-one-failed" && <ServiceLinkNew serviceKey="occmSetupService" text="Start Free Trial"/>}
            { occms.view === "has-many" && <Link to="/cloud-managers" className="button service-link">Go to Cloud Managers</Link>}
            { occms.view === "failed" && <div style={{position: "absolute", top: 165, width: "100%", height: "55px", lineHeight: "55px"}}>Error loading OCCMs..</div> }
            { (occms.view === "has-one-failed" || occms.view === "has-one-ready")  && <Link to="/cloud-managers" className="edit-cloud-manager"  style={{position: "absolute", top: 215, width: "100%", left: 0, color: "#636363"}}>Edit Cloud Manager</Link> }
            { occms.view === "has-one-initializing" && <ServiceLinkNew serviceKey="occmSetupService" style={{position: "absolute", top: 215, width: "100%", backgroundColor: "transparent", color: "#636363"}} text="Create Cloud Manager"/>}
            <MoreInfoLinkNew serviceKey="ontapCloud"/>
            {
                occms.view === "has-one-initializing" && <BarLoader className="bottom"/>
            }
            {
                occms.view === "has-one-initializing"  && isOlderThanThirtyMinutes(occms.data.occms[0].createDate)  &&
                <Popover trigger="mouseover" containerStyle={{cursor: "pointer", bottom: "-16px", position: "absolute", left: "0", right: "0"}} className={popoverStyle['info']} component={
                    <div className="error-text warning">
                        <WarningIcon style={{position: "relative", top: 18, width: 15, color: "#ffa100"}} /><span style={{color: "#ffa100"}}>Launch is hanging...</span>
                    </div>
                }>
                    There may be a problem deploying this Cloud Manager system. Go to your cloud provider’s console to find the IP address for the system and then log in to complete the setup process. If you need help, contact us by clicking the chat icon in the lower right of your web browser.
                </Popover>
            }
            {
                occms.view === "has-one-failed" &&
                <div className="error-text" style={{bottom: "-28px", position: "absolute", left: "0", right: "0"}}>
                    OCCM Instance Failed to Launch
                </div>
            }
        </div>
    </div>
;

const CloudVolumesServiceBox = ({openDialog, isDialogOpen, closeTrigger}) => {
    let buttonRef = React.createRef();

    return <div className="grid-box">
        <div className="box">
            <CloudVolumesLogo/>
            <div className="title">Cloud Volumes Service</div>
            <button className="button service-link" ref={buttonRef} onClick={openDialog}>
                Get Started
            </button>
            <Dialog target={() => buttonRef.current} open={isDialogOpen} closeTrigger={closeTrigger}>
                <SelectCloudVolumesDialog className="select-cloud-volumes-dialog"/>
            </Dialog>
            <MoreInfoLinkNew serviceKey="cloudVolumesServiceAws"/>
        </div>
    </div>;
};


const CloudSecureBox = ({serviceData}) =>
    <div className="grid-box">
        <div className="box">
            <CloudSentryLogo/>
            <div className="title">Cloud Secure</div>
            <ServiceLinkNew serviceKey={serviceData.serviceKey} text={serviceData.text}/>
            <MoreInfoLinkNew serviceKey="cloudSecure"/>
        </div>
    </div>
;

const CloudTieringBox = ({serviceData}) =>
    <div className="grid-box">
        <div className="box">
            <CloudTieringLogo/>
            <div className="title">Cloud Tiering</div>
            <ServiceLinkNew serviceKey={serviceData.serviceKey} text={serviceData.text}/>
            <MoreInfoLinkNew serviceKey="cloudTiering"/>
        </div>
    </div>
;

const CloudBackupBox = ({serviceData}) =>
    <div className="grid-box">
        <div className="box">
            <CloudBackupLogo/>
            <div className="title">Cloud Backup Service</div>
            <ServiceLinkNew serviceKey={serviceData.serviceKey} text={serviceData.text}/>
            <MoreInfoLinkNew serviceKey="cloudBackup"/>
        </div>
    </div>
;

const KubernetesServiceBox = ({serviceData}) =>
    <div className="grid-box">
        <div className="box">
            <KubernetesServiceLogo/>
            <div className="title">NetApp Kubernetes Service</div>
            <ServiceLinkNew serviceKey={serviceData.serviceKey} text={serviceData.text}/>
            <MoreInfoLinkNew serviceKey="kubernetesService"/>
        </div>
    </div>
;

const LaunchPad = ({openCloudVolumesDialog, closeCloudVolumesDialog, cloudVolumesDialogOpen, occms, auth, activeFeatures, kubernetesService, services}) =>
    <div className="launch-pad">
        <div className="grid-container">
            <div className="grid-row">
                <CloudVolumesServiceBox openDialog={openCloudVolumesDialog} closeTrigger={closeCloudVolumesDialog} isDialogOpen={cloudVolumesDialogOpen}/>
                <CloudVolumesONTAPBox occms={occms}/>
                <KubernetesServiceBox serviceData={services.kubernetesService}/>
                <CloudInsightsBox serviceData={services.cloudInsights}/>
                <CloudSyncBox serviceData={services.cloudSync} />
                <SaasBackupBox serviceData={services.saasBackup}/>
                <CloudSecureBox serviceData={services.cloudSecure}/>
                <CloudTieringBox serviceData={services.cloudTiering}/>
                <CloudBackupBox serviceData={services.cloudBackup}/>
            </div>
        </div>
    </div>
;

const mapStateToProps = state => {
    return {
        services: state.services,
        occms: state.services.cloudVolumesOntap,
        cloudVolumesDialogOpen: state.services.cloudVolumesDialogState === 'myServices',
        auth: state.auth,
        activeFeatures: state.features.active
    };
};

const mapDispatchToProps = dispatch => {
    return {
        openCloudVolumesDialog: () => {
            dispatch({
                type: "LAUNCHPAD:OPEN-CLOUD-VOLUMES-SERVICE-DIALOG",
                payload: {
                    origin: 'myServices'
                }
            })
        },
        closeCloudVolumesDialog: () => {
            dispatch({
                type: "LAUNCHPAD:CLOSE-CLOUD-VOLUMES-SERVICE-DIALOG"
            })
        }
    }
};

export default connect(mapStateToProps, mapDispatchToProps)(LaunchPad)