import React, { Component } from 'react'
import "./SolutionsPane.scss";
import list from "ui-components/src/list/list.module.scss";
import { ReactComponent as DisasterRecoveryIcon } from "ui-components/src/images/workloads/ic-disaster-recovery.svg"
import { ReactComponent as EnterpriseApplicationIcon } from "ui-components/src/images/workloads/ic-enterprise.svg"
import { ReactComponent as SaasApplicationsIcon } from "ui-components/src/images/workloads/ic-saas-app.svg"
import { ReactComponent as SaasDataBackupIcon } from "ui-components/src/images/workloads/ic-backup.svg"
import { ReactComponent as FileServicesIcon } from "ui-components/src/images/workloads/ic-file-services.svg"
import { ReactComponent as AnalyticsIcon } from "ui-components/src/images/workloads/ic-analytics.svg"
import { ReactComponent as DevopsIcon } from "ui-components/src/images/workloads/ic-devops.svg"
import { ReactComponent as DatabaseIcon } from "ui-components/src/images/workloads/ic-database.svg"
import { launchPadTracker } from "./../../eventTrackers";
import _ from 'lodash'
import classNames from "classnames";


const track = launchPadTracker({action: "ClickWorkload"});
const trackReadMore = launchPadTracker({action: "ReadMoreWorkload"});

const parentHasClass = (node, className) => {
    return (node.classList && node.classList.contains(className)) || (node.parentNode && parentHasClass(node.parentNode, className));
};


const workloads = [
    {
        key: "enterpriseApplications",
        image: EnterpriseApplicationIcon,
        title: "Enterprise Workloads",
        text: [
            "Run your workloads uninterruptedly, securely, and efficiently",
            "Ensure business continuity with RPO=0, RTO < 60 secs high availability",
            "Protect your data with efficient snapshot technology and disaster recovery",
            "Reduce costs and footprint by 50 to 70% with storage efficiency features and data tiering"
        ]
    },
    {
        key: "saasApplications",
        image: SaasApplicationsIcon,
        title: "SaaS Application",
        text: [
            "Scale up development, reduce costs while staying fast and agile",
            "Reduce storage footprint and costs by 50 to 70% with storage efficiencies",
            "Increase agility and speed-up TTM and DevOps processes with data cloning",
            "Leverage management frontend to streamline processes, automation and orchestration"
        ]
    },
    {
        key: "disasterRecovery",
        image: DisasterRecoveryIcon,
        title: "Disaster Recovery",
        text: [
            "Cost-effective cloud secondary copy, supporting seamless, quick failover and failback",
            "Reduce costs with data compression, deduplication, and data tiering",
            "Synchronize data efficiently and automatically, for point-in-time recovery",
            "Manage automatic failover and quick, efficient failback processes"
        ]
    },
    {
        key: "saasDataBackup",
        image: SaasDataBackupIcon,
        title: "Backup & Archive",
        text: [
            "Guard your SaaS data from threats or accidental deletion",
            "Protect your critical Microsoft 365 data",
            "Meet compliance requirement",
            "Leverage all-in-one service"
        ]
    },
    {
        key: "fileServices",
        image: FileServicesIcon,
        title: "File Services",
        text: [
            "Get file access, sharing, protection, and management in any geography and scale",
            "Support for both NFS and SMB/CIFS file shares",
            "Support shared file access across Windows and Unix/Linux Operating Systems",
            "Complete integration with file directory metadata"
        ]
    },
    {
        key: "analytics",
        image: AnalyticsIcon,
        title: "Analytics",
        text: [
            "Leverage data management, collaboration and mobility services to analyze massive data amounts",
            "Enable seamless data synchronization to and from multiple sources",
            "Integrate with public cloud analytics such as Amazon EMR and Amazon Redshift",
            "Keep data secure  with encrypted, hybrid and multicloud data mobility"
        ]
    },
    {
        key: "devops",
        image: DevopsIcon,
        title: "DevOps",
        text: [
            "Durable, high performance, on-demand, instant volume creation",
            "Increased agility and faster TTM for dev/test with instant data clones",
            "Save costs with writeable clones charging only for data changes",
            "Meet containerized workloads persistent storage demands (Docker, Kubernetes)"
        ]
    },
    {
        key: "database",
        image: DatabaseIcon,
        title: "Database",
        text: [
            "Protect your data, increase performance, improve efficiency",
            "Leverage performance at the highest levels and guaranteed SLAs",
            "Support multiple Availability Zones and enable business continuity with no data loss",
            "Gain flexibility that your cloud solution needs to support multiple database engines"
        ]
    }
];

const WorkloadCard = ({image: Image, title, workloadKey, setActive, isActive, show, classString, text, refHolder}) =>
    <div className="grid-box">
        <button className={classNames("box", {active: isActive})} onClick={() => {
            track(workloadKey);
            setActive();
        }}>
            <Image className="icon"/>
            <div className="title">{title}</div>
            <div className="the-thin-blue-line"/>
        </button>
        <div className={classNames("slider-holder", classString)} ref={(el) => { refHolder[workloadKey] = el; }}>
            {show && <div className="arrow"/>}
            {show && <div className={classNames("text-panel", workloadKey)}>
                <h4>{text[0]}</h4>
                <ul className={list["disc-ul"]}>
                    {_(text).drop(1).map((el, i) => <li key={i}><span>{el}</span></li>).value()}
                </ul>
                {
                    window.__marketing.solutions[workloadKey] &&
                    <a className="read-more" href={window.__marketing.solutions[workloadKey]} onClick={() => {trackReadMore(workloadKey)}}>Read More</a>
                }
            </div>}
            {show && <div className={classNames("text-panel-filler", workloadKey)} />}
        </div>
    </div>;

let animateKey = 0;
const animateDuration = 416;

export class SolutionsGrid extends Component {
    constructor(props){
        super(props);
        this.state = {animate: {}};
    }


    componentDidMount() {
        this.clickAwayListener = (e) => {
            if(!parentHasClass(e.target, "grid-box")){
                this.setState({active: null, animate: {[this.state.active]: "leave"}});

                animateKey = animateKey + 1;
                const animateSave = animateKey;

                setTimeout(() => {
                    if(animateKey === animateSave && !this.cancelAnimate) this.setState({animate: {}});
                }, animateDuration);
            }
        };
        window.document.body.addEventListener("click", this.clickAwayListener);
    }

    componentWillUnmount() {
        this.cancelAnimate = true;
        window.document.body.removeEventListener("click", this.clickAwayListener);
    }

    setActive (key) {
        if(this.state.active === key) {
            animateKey = animateKey + 1;
            const animateSave = animateKey;

            this.setState({active: null, animate: {[this.state.active]: "leave"}});
            setTimeout(() => {
                if(animateKey === animateSave) this.setState({animate: {}});
            }, animateDuration);
        }
        else {
            const prevKey = this.state.active;
            const prevEl = this[prevKey];
            const currentEl = this[key];

            const prevTop = prevEl ? prevEl.getBoundingClientRect().top : null;
            const currentTop = currentEl.getBoundingClientRect().top;

            const isSameHeight = prevTop === currentTop;

            animateKey = animateKey + 1;
            const animateSave = animateKey;

            this.setState({active: key, animate: isSameHeight ? {[key]: "fade-in", [prevKey]: "fade-out"} : {[key]: "enter", [prevKey]: "leave"}}, () => {
                this.setState({animate: isSameHeight ? {[key]: "fade-in-active", [prevKey]: "fade-out"} : {[key] : "enter-active", [prevKey]: "leave"}});
                setTimeout(() => {
                    if(animateKey === animateSave) this.setState({animate: {}});
                }, animateDuration);
            });
        }
    }

    render () {
        return <div className="grid-row">
            {workloads.map (({key, image, title, text}) =>
                <WorkloadCard refHolder={this} key={key} workloadKey={key} text={text} image={image} title={title} classString={this.state.animate[key]} show={this.state.animate[key] || this.state.active === key} isActive={this.state.active === key} setActive={() => this.setActive(key)}/>
            )}
        </div>
    }
}