import React from 'react'
import { registerFeature } from "../../middlewares/apiMiddleware";
import subscriptionsMiddleware from "../../middlewares/featureApis/subscriptionsMiddleware";
import _ from "lodash";
import store from "../../store";
import connect from "react-redux/es/connect/connect";
import Loader from "../../Loader";
import {Dialog} from "../dialog/Dialog";
import styles from "./SubscriptionMapping.module.scss";
import dialogStyles from "ui-components/src/dialog/dialog.module.scss"
import {ReactComponent as CloseXIcon} from "ui-components/src/images/monochrome-icons/x-icon.svg";
import {history} from "../../store";
import {ReactComponent as SuccessIcon} from "ui-components/src/images/monochrome-icons/ic-success.svg";
import {ReactComponent as ErrorIcon} from "ui-components/src/images/monochrome-icons/ic-success.svg";
import buttons from "ui-components/src/button/button.module.scss";
import ExternalLink from "../widgets/ExternalLink";
import {Link} from "react-router-dom";

registerFeature("SUBSCRIPTIONS", subscriptionsMiddleware);

const serviceMapping = {
    "cloud-tiering": {
        title: "Cloud Tiering",
        link: "launchPad.services.cloudTiering"
    },
    "cloud-volumes-ontap": {
        title: "Cloud Volumes ONTAP",
        link: "launchPad.services.cloudVolumesOntap"
    },
    "test-service": {
        title: "[TEST] NetApp SaaS Subscription Service",
        link: "/"
    }
};

const cloudProviderMapping = {
    "aws": "AWS Marketplace"
};

const fetch = _.once(({cloudProvider, token}) => {
    if(cloudProvider === "aws") {
        store.dispatch({
            type: "SUBSCRIPTIONS:RESOLVE-AWS-TOKEN",
            payload: {
                registrationToken: token
            }
        })
    } else {
        console.log(`Invalid cloudProvider ${cloudProvider}`);
    }
    history.replace("/subscription-mapping");
});

const mapStateToProps = state => {
    return {
        subscription: state.subscriptions.subscription,
        subscriptionError: state.subscriptions.subscriptionError,
        subscriptionStatus: state.subscriptions.subscriptionStatus
    };
};

const SubscriptionMappingDialogDumb = ({cloudProvider, serviceName, token, redirectError, subscription, subscriptionError, subscriptionStatus, closeDialog}) => {
    const service = serviceMapping[serviceName];
    const cloudProviderTitle = cloudProviderMapping[cloudProvider];

    if(!service || !cloudProviderTitle) {
        return <div>
            Invalid service or cloud provider specified specified.
        </div>
    } else {
        const isError = redirectError || subscriptionStatus === "ERROR";
        if(subscriptionStatus === "PENDING" && !isError) {
            return <div><Loader/></div>
        } else {
            return <div>
                    <header>
                        Subscription Assignment
                        <button onClick={closeDialog}><CloseXIcon/></button>
                    </header>
                    <div className={isError ? styles['content-error'] : styles['content-success']}>
                        {isError && <div className={styles["banner-error"]}>
                            <ErrorIcon/>
                            <div>We're unable to create your subscription to</div>
                            <div><span>{service.title}</span> from <span>{cloudProviderTitle}</span></div>
                        </div>}
                        {!isError && <div className={styles["banner-success"]}>
                            <SuccessIcon/>
                            <div>Your subscription to</div>
                            <div><span>{service.title}</span> from <span>{cloudProviderTitle}</span></div>
                            <div>was created successfully!</div>
                        </div>}
                        {!isError && <div className={styles.content}>
                            <div>Your subscription name is: <span>{subscription.subscriptionName}</span></div>
                            {subscription.newAccountCreated && <div>We've assigned your subscription to a new account: <span>{subscription.newAccountName}</span></div>}
                            {!subscription.newAccountCreated && <React.Fragment>
                                <div>We've assigned your subscription to all of your accounts:</div>
                                <div><span>{subscription.accounts.map(account => account.accountName).join(", ")}</span></div>
                            </React.Fragment>}
                        </div>}
                        {isError && <div className={styles.content}>
                            <div style={{fontWeight: "bolder"}}>{redirectError || subscriptionError}</div>
                            <div>In order to complete the subscription assignment process you will need to unsubscribe and resubscribe in the marketplace.</div>
                        </div>}
                    </div>
                    <div className={styles.footer}>
                        <div className={dialogStyles["button-pair-wrapper"]}>
                            <Link to="/" className={buttons.cancel} onClick={closeDialog}>Done</Link>
                            <ExternalLink className={buttons.primary} linkKey={service.link} trackCategory="subscriptionMapping">Go to {service.title}</ExternalLink>
                        </div>
                        {!isError && <div className={styles['footer-info']}>If you want to update your subscription assignment please go to the products <span>'Account Settings'</span></div>}
                    </div>
                </div>
        }
    }
};

const SubscriptionMappingDialog = connect(mapStateToProps)(SubscriptionMappingDialogDumb);

const SubscriptionMapping = ({cloudProvider, serviceName, token, error}) => {
    fetch({cloudProvider, token});
    return <Dialog open={true} closeTrigger={() => history.replace("/")}>
            <SubscriptionMappingDialog serviceName={serviceName} cloudProvider={cloudProvider} redirectError={error} className={styles.dialog}/>
        </Dialog>
};

export default SubscriptionMapping;
