import axios from "axios"
import links from "./../../consts/links"
import _ from "lodash";
import store from "../../store";
import * as actions from "../../actions";

export default ({getState, dispatch, next, action}) => {
    const {type, payload} = action;

    if (type === "LAUNCHPAD:UPDATE-OCCM-URIS") {
        const {occmId, uris: redirectUris} = payload;
        const promise = axios.post("/occm/manual-update-uris", {
            occmId,
            redirectUris
        });

        promise.then(
            r => dispatch({type: "LAUNCHPAD:UPDATE-OCCM-URIS-SUCCESS", payload: r}),
            e => dispatch({type: "LAUNCHPAD:UPDATE-OCCM-URIS-ERROR", payload: e}));

        return next({type: "LAUNCHPAD:UPDATE-OCCM-URIS-PENDING"});
    } else if (type === "LAUNCHPAD:REMOVE-OCCM") {
        const {occmId} = payload;

        const promise =  axios.post("/occm/deassociate-self", {
            occmId
        });

        promise.then(
            r => dispatch({type: "LAUNCHPAD:REMOVE-OCCM-SUCCESS", payload: r}),
            e => dispatch({type: "LAUNCHPAD:REMOVE-OCCM-ERROR", payload: e}));

        return next({type: "LAUNCHPAD:REMOVE-OCCM-PENDING"});
    } else if (type === "LAUNCHPAD:FETCH-CLOUD-SYNC-USER-INFO") {
        const promise = axios.get(links.launchPad.services.cloudSyncBackend + "/api/users/info?noCreate=true");

        promise.then(
            r => dispatch({type: "LAUNCHPAD:FETCH-CLOUD-SYNC-USER-INFO-SUCCESS", payload: r}),
            e => dispatch({type: "LAUNCHPAD:FETCH-CLOUD-SYNC-USER-INFO-ERROR", payload: e}));

        return next({type: "LAUNCHPAD:FETCH-CLOUD-SYNC-USER-INFO-PENDING"});
    } else if (type === "LAUNCHPAD:FETCH-CLOUD-INSIGHT-USER-INFO") {
        const promise = axios.get(links.launchPad.services.cloudInsightsBackend + "/rest/v1/user");

        promise.then(
            r => dispatch({type: "LAUNCHPAD:FETCH-CLOUD-INSIGHT-USER-INFO-SUCCESS", payload: r}),
            e => dispatch({type: "LAUNCHPAD:FETCH-CLOUD-INSIGHT-USER-INFO-ERROR", payload: e}));

        return next({type: "LAUNCHPAD:FETCH-CLOUD-INSIGHT-USER-INFO-PENDING"});
    } else if (type === "LAUNCHPAD:FETCH-CLOUD-VOLUMES-SERVICE-AWS-USER-INFO") {
        if(_.get(store.getState(), "features.active.cloudVolumesRegisteredQuery", false)){
            const promise = axios.get(links.launchPad.services.cloudVolumesServiceAwsBackend + "/api/cloud-volumes/account-status");

            promise.then(
                r => dispatch({type: "LAUNCHPAD:FETCH-CLOUD-VOLUMES-SERVICE-AWS-USER-INFO-SUCCESS", payload: r}),
                e => dispatch({type: "LAUNCHPAD:FETCH-CLOUD-VOLUMES-SERVICE-AWS-USER-INFO-ERROR", payload: e}));

            return next({type: "LAUNCHPAD:FETCH-CLOUD-VOLUMES-SERVICE-AWS-USER-INFO-PENDING"});
        } else {
            dispatch({type: "LAUNCHPAD:FETCH-CLOUD-VOLUMES-SERVICE-AWS-USER-INFO-SUCCESS", payload: {
                data: {
                    registered: true
                }
            }})
        }
    } else if (type === "LAUNCHPAD:LOAD-SERVICE-DEFAULT-STATES") {
        const activeFeatures = _.get(store.getState(), "features.active", {});

        return next({
            type: "LAUNCHPAD:LOAD-SERVICE-DEFAULT-STATES",
            payload: {
                saasBackup: {status: actions.STATUS_SUCCESS, text: "Start Free Trial", serviceKey: "saasBackup"},
                // cloudVolumesOntap: {status: actions.STATUS_PENDING, view: "loading"},
                cloudSecure: {status: actions.STATUS_SUCCESS, text: "Register for Preview", serviceKey: activeFeatures.cloudSecureLink ? "cloudSecure" : "cloudSecurePreview"},
                cloudTiering: {status: actions.STATUS_SUCCESS, text: "Go to Cloud Tiering", serviceKey: "cloudTiering"},
                cloudBackup: {status: actions.STATUS_SUCCESS, text: "Register for Preview", serviceKey: "cloudBackupPreview"},
                kubernetesService: {status: actions.STATUS_SUCCESS, text: "Start Free Trial", serviceKey: "kubernetesService"}
            }
        })
    }


    return next(action);
};
