import * as actions from "../actions";
import _ from "lodash";
import numeral from "numeral";

/*eslint default-case: 0*/

const defaultState = () => ({
    occmDemo: {status: actions.STATUS_NOT_SENT},
    refreshToken: {status: actions.STATUS_NOT_SENT},
    integrationInstructionsOpenRow: "Introduction",
    americasGlobalSpiffStatus: "PENDING",
    americasGlobalSpiffData: {}
});

export default (state = defaultState(), {payload, type, status}) => {
    switch(type){
        case "INTERNAL:OCCM-DEMO": {
            switch (status){
                case actions.STATUS_SUCCESS:
                    return { ...state, occmDemo: {status: actions.STATUS_SUCCESS, data: payload.data}};
                case actions.STATUS_ERROR:
                    return { ...state, occmDemo: {status: actions.STATUS_ERROR}};
                case actions.STATUS_PENDING:
                    return { ...state, occmDemo: {status: actions.STATUS_PENDING}};
            }
            break;
        }
        case "OCCM-DEMO-RESET": {
            return { ...state, occmDemo: {status: actions.STATUS_NOT_SENT }};
        }
        case "GET-REFRESH-TOKEN": {
            switch (status) {
                case actions.STATUS_SUCCESS:
                    return {...state, refreshToken: {status: actions.STATUS_SUCCESS, data: payload.data}};
                case actions.STATUS_ERROR:
                    return {...state, refreshToken: {status: actions.STATUS_ERROR, data: payload.data}};
                case actions.STATUS_PENDING:
                    return { ...state, refreshToken: {status: actions.STATUS_PENDING}};
            }
            break;
        }
        case "INTERNAL:INTEGRATION-INSTRUCTIONS-TOGGLE-ROW": {
            let newRow = null;
            if(state.integrationInstructionsOpenRow !== payload){
                newRow = payload;
            }
            return {...state, integrationInstructionsOpenRow: newRow}
        }
        case "INTERNAL:FETCH-AMERICAS-GLOBAL-SPIFF-DATA-PENDING": {
            return {...state, americasGlobalSpiffStatus: "PENDING", americasGlobalSpiffData: {} }
        }
        case "INTERNAL:FETCH-AMERICAS-GLOBAL-SPIFF-DATA-SUCCESS": {
            const teamChallenge = payload.teamChallenge;
            const individualChallengeRules = payload.individualChallengeRules;
            const individualChallengeRunners = payload.individualChallengeRunners;
            const partnerReport = payload.partnersReport;

            const areaMapper = {
                "Enterprise": "enterprise",
                "Commercial": "commercial",
                "USPS": "usps",
                "Canada/LATAM": "canada-latam",
                "Globals": "globals"
            };

            individualChallengeRules.forEach(rule => {
                rule.area = areaMapper[rule.Area] || areaMapper["Globals"];
                rule.category = rule.Geo === "Globals" ? `${rule.Area}-${rule.Title}` : rule.Title;
                rule.target = rule["Target Licenses"];
                rule.vouchers = rule["Available Vouchers"];
            });

            const rulesByAreas = _.groupBy(individualChallengeRules, "area");

            const titleMapper = {
                "GEM": "GEM/Account Owner",
                "TAM": "TAM/SE"
            };

            individualChallengeRunners.forEach(winner => {
                winner.area = areaMapper[winner.Area] || areaMapper["Globals"];
                winner.role = winner.Geo === "Globals" ? titleMapper[winner.Title] : winner.Title;
                winner.name = winner.Name;
                winner.licenses = winner.Licenses;
                winner.index = winner["Winner Index"] && parseInt(winner["Winner Index"]);
                winner.category = winner.Geo === "Globals" ? `${winner.Area}-${winner.role}` : winner.role;
            });

            const runnersByAreas = _.groupBy(individualChallengeRunners, "area");

            teamChallenge.forEach((district) => {
                district.fValue = numeral(district.Revenue).format('$0,0');
                district.name = district["District/Region"];
                district.value = parseFloat(district.Revenue);
                district.passesThreshold = Number(district["Licenses"]) >= Number(district["Minimum Licenses"]) && Number(district["Customers"]) >= Number(district["Minimum Customers"]);
                district.area = areaMapper[district["Geo/Area"]];
                district.numberOfCustomers = district["Customers"];
                district.numberOfLicenses = district["Licenses"];
                district.minimumNumberOfLicenses = district["Minimum Licenses"];
                district.minimumNumberOfCustomers = district["Minimum Customers"]
            });

            const teamChallengeByDistricts = _(teamChallenge).sortBy("value").groupBy("area").value();

            _.forEach(teamChallengeByDistricts, area => {
                _.forEach(_.reverse(area), (district, place) => {
                    district.place = place + 1;
                })
            });

            partnerReport.forEach((partner) => {
                partner.fValue = numeral(partner.Booking).format('$0,0');
                partner.value = parseFloat(partner.Booking);
                partner.name = partner.Name;
            });

            const partnersReportByBookings = _(partnerReport)
                .sortBy("value")
                .reverse()
                .value();

            return {...state, americasGlobalSpiffStatus: "SUCCESS", americasGlobalSpiffData: { accounts: payload.accounts , teamChallenge: teamChallengeByDistricts, rules: rulesByAreas, runners: runnersByAreas, partners: partnersReportByBookings}};
        }
        case "INTERNAL:FETCH-AMERICAS-GLOBAL-SPIFF-DATA-ERROR": {
            return {...state, americasGlobalSpiffStatus: "ERROR", americasGlobalSpiffError: _.get(payload, "response.data.message", "Failed to save fetch spiff data.")}
        }
        case "INTERNAL:OPEN-DIALOG-AMERICAS-GLOBALS": {
            const districts = state.americasGlobalSpiffData.teamChallenge[payload.area];
            return {...state, americasGlobalSpiffDistrictDialog: payload.districtName, americasGlobalSpiffSelectedDistrict: _.find(districts, {name: payload.districtName})}
        }
        case "INTERNAL:CLOSE-DIALOG-AMERICAS-GLOBALS": {
            return {...state, americasGlobalSpiffDistrictDialog: null}
        }
    }
    return state;
};